@@ -126,19 +126,21 @@ const char * irplib_parameterlist_get_string(const cpl_parameterlist * self,
                                              const char * recipe,
                                              const char * parameter)
 {
-
     const cpl_parameter * par = irplib_parameterlist_get(self, instrume,
                                                          recipe, parameter);
-    const char * value;
 
-    cpl_ensure(par != NULL, cpl_error_get_code(), NULL);
+    if (par == NULL) {
 
-    value = cpl_parameter_get_string(par);
+        (void)cpl_error_set_where(cpl_func);
 
-    if (value == NULL) (void)cpl_error_set_where(cpl_func);
+        return NULL;
+    } else {
+        const char * value = cpl_parameter_get_string(par);
 
-    return value;
+        if (value == NULL) (void)cpl_error_set_where(cpl_func);
 
+        return value;
+    }
 }
 
 /*----------------------------------------------------------------------------*/
@@ -157,21 +159,23 @@ cpl_boolean irplib_parameterlist_get_bool(const cpl_parameterlist * self,
                                           const char * recipe,
                                           const char * parameter)
 {
-
     const cpl_parameter * par = irplib_parameterlist_get(self, instrume,
                                                          recipe, parameter);
-    cpl_errorstate        prestate = cpl_errorstate_get();
-    cpl_boolean           value;
 
+    if (par == NULL) {
 
-    cpl_ensure(par != NULL, cpl_error_get_code(), CPL_FALSE);
+        (void)cpl_error_set_where(cpl_func);
 
-    value = cpl_parameter_get_bool(par);
+        return CPL_FALSE;
+    } else {
+        cpl_errorstate    prestate = cpl_errorstate_get();
+        const cpl_boolean value    = cpl_parameter_get_bool(par);
 
-    if (!cpl_errorstate_is_equal(prestate)) (void)cpl_error_set_where(cpl_func);
-
-    return value;
+        if (!cpl_errorstate_is_equal(prestate))
+            (void)cpl_error_set_where(cpl_func);
 
+        return value;
+    }
 }
 
 
@@ -191,20 +195,23 @@ int irplib_parameterlist_get_int(const cpl_parameterlist * self,
                                  const char * recipe,
                                  const char * parameter)
 {
-
     const cpl_parameter * par = irplib_parameterlist_get(self, instrume,
                                                          recipe, parameter);
-    cpl_errorstate        prestate = cpl_errorstate_get();
-    int                   value;
 
+    if (par == NULL) {
 
-    cpl_ensure(par != NULL, cpl_error_get_code(), 0);
+        (void)cpl_error_set_where(cpl_func);
 
-    value = cpl_parameter_get_int(par);
+        return 0;
+    } else {
+        cpl_errorstate prestate = cpl_errorstate_get();
+        const int      value    = cpl_parameter_get_int(par);
 
-    if (!cpl_errorstate_is_equal(prestate)) (void)cpl_error_set_where(cpl_func);
+        if (!cpl_errorstate_is_equal(prestate))
+            (void)cpl_error_set_where(cpl_func);
 
-    return value;
+        return value;
+    }
 }
 
 /*----------------------------------------------------------------------------*/
@@ -223,20 +230,23 @@ double irplib_parameterlist_get_double(const cpl_parameterlist * self,
                                        const char * recipe,
                                        const char * parameter)
 {
-
     const cpl_parameter * par = irplib_parameterlist_get(self, instrume,
                                                          recipe, parameter);
-    cpl_errorstate        prestate = cpl_errorstate_get();
-    double                value;
 
+    if (par == NULL) {
 
-    cpl_ensure(par != NULL, cpl_error_get_code(), 0.0);
+        (void)cpl_error_set_where(cpl_func);
 
-    value = cpl_parameter_get_double(par);
+        return 0.0;
+    } else {
+        cpl_errorstate prestate = cpl_errorstate_get();
+        const double   value    = cpl_parameter_get_double(par);
 
-    if (!cpl_errorstate_is_equal(prestate)) (void)cpl_error_set_where(cpl_func);
+        if (!cpl_errorstate_is_equal(prestate))
+            (void)cpl_error_set_where(cpl_func);
 
-    return value;
+        return value;
+    }
 }
 
 /*----------------------------------------------------------------------------*/
