@@ -1,7 +1,6 @@
-/* $Id: irplib_wlxcorr.c,v 1.58 2013-01-29 08:43:33 jtaylor Exp $
- *
+/*
  * This file is part of the IRPLIB package
- * Copyright (C) 2002,2003 European Southern Observatory
+ * Copyright (C) 2002,2003,2014 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02111-1307  USA
  */
 
-/*
- * $Author: jtaylor $
- * $Date: 2013-01-29 08:43:33 $
- * $Revision: 1.58 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -33,15 +25,15 @@
    								Includes
  -----------------------------------------------------------------------------*/
 
-#include <math.h>
-#include <string.h>
-
-#include <cpl.h>
-
 #include "irplib_wavecal_impl.h"
 
 #include "irplib_wlxcorr.h"
 
+#include <cpl.h>
+
+#include <math.h>
+#include <string.h>
+
 /*----------------------------------------------------------------------------*/
 /**
  * @defgroup irplib_wlxcorr     Wavelength Cross correlation w. plotting
@@ -58,13 +50,6 @@
                            Defines
  -----------------------------------------------------------------------------*/
 
-/* TEMPORARY SUPPORT OF CPL 5.x */
-#ifndef CPL_SIZE_FORMAT
-#define CPL_SIZE_FORMAT "d"
-#define cpl_size int
-#endif
-/* END TEMPORARY SUPPORT OF CPL 5.x */
-
 #ifndef inline
 #define inline /* inline */
 #endif
@@ -892,7 +877,7 @@ int irplib_wlxcorr_catalog_plot(
         cpl_msg_error(cpl_func, "Cannot plot the catalog") ;
         return -1 ;
     }
-    nvals = start - stop + 1 ;
+    nvals = stop - start + 1 ;
 
     /* Create the bivector to plot */
     subcat_x = cpl_vector_extract(cpl_bivector_get_x_const(cat),start,stop, 1) ;
