@@ -321,14 +321,16 @@ xsh_params_set_defaults(cpl_parameterlist* pars,
    cpl_parameter* p=NULL;
 
   if (xsh_instrument_get_arm(inst) == XSH_ARM_UVB){
-     check(p=xsh_parameters_find(pars,RECIPE_ID,"kappa"));
+
+      p=cpl_parameterlist_find(pars, "xshoo.xsh_lingain.kappa");
+
      if(xsh_parameter_get_default_flag(p) == 0) {
+     //if( fabs(val-def) > DBL_MIN ) {
         /* if the user has not set the parameter use default */
         cpl_parameter_set_double(p,5.);
      }    
   }
 
-
  cleanup:
  
   return cpl_error_get_code();
@@ -436,7 +438,7 @@ xsh_lingain(cpl_frameset            * frameset,
 
     //xsh_lingain_pre_format(raws,instrument,bpmap,0,&frameset);
 
-    xsh_lingain_fill_parlist_default_opt(plist);
+    check(xsh_lingain_fill_parlist_default_opt(plist));
     check(xsh_params_set_defaults(parlist,instrument));
     xsh_lingain_set_saturation_limit(plist,instrument);
 
