@@ -544,13 +544,13 @@ xsh_qc_ifu_flat(cpl_frame* mflat,xsh_instrument* instrument)
 
     if(do_it) {
         xsh_pre* pre = xsh_pre_load(mflat,instrument);
-        double s1r;
-        double s2r;
-        double s3r;
+        double s1r=0;
+        double s2r=0;
+        double s3r=0;
 
-        double s1b;
-        double s2b;
-        double s3b;
+        double s1b=0;
+        double s2b=0;
+        double s3b=0;
 
         if (xsh_instrument_get_arm(instrument) == XSH_ARM_UVB){
 
