@@ -118,7 +118,6 @@ Tag = OBJECT_SLIT_NOD_arm\n\
   - A standard star fluxes catalog (Tag = FLUX_STD_CATALOG_arm Type = FLX)\n\
   - A table to set response sampling points (Tag = RESP_FIT_POINTS_CAT_arm)\n\
   - [OPTIONAL] An atmospheric extinction table (Tag = ATMOS_EXT_arm)\n\
-  - [OPTIONAL] An master response curve table (Tag = MRESPONSE_MERGE1D_SLIT_arm)\n\
     if provided this is the one used to flux calibrate the spectra\n\
 Products : \n\
   - [If STD is in catal] The response function (Tag = PREFIX_RESPONSE_ORDER1D_SLIT_arm)\n\
@@ -451,7 +450,6 @@ xsh_respon_slit_nod( cpl_parameterlist* parameters,
   cpl_frame *frm_eff = NULL;
   cpl_frame* response_ord_frame=NULL;
   cpl_frame* response_frame=NULL;
-  cpl_frame* mresponse_frame=NULL;
   cpl_frame * fluxcal_1D_frame = NULL ;	/**< Final (result) frame */
   cpl_frame * fluxcal_2D_frame = NULL ;	/**< Final (result) frame */
   cpl_frame * fluxcal_rect_1D_frame = NULL ;	/**< Final (result) frame */
@@ -575,11 +573,6 @@ xsh_respon_slit_nod( cpl_parameterlist* parameters,
   }
 
   /* QC extra frames */
-  if((mresponse_frame=xsh_find_frame_with_tag(calib,XSH_MRESPONSE_MERGE1D_SLIT,
-                                             instrument)) != NULL ) {
-     xsh_msg("Using the master response curve to flux calibrate the spectrum");
-  }
-
   resp_fit_points_cat_frame=xsh_find_frame_with_tag(calib,XSH_RESP_FIT_POINTS_CAT,instrument);
   if(resp_fit_points_cat_frame==NULL) {
      xsh_msg_warning("Missing input %s_%s response will not be computed",
@@ -756,14 +749,7 @@ xsh_respon_slit_nod( cpl_parameterlist* parameters,
      }
   }
 
-  if(mresponse_frame != NULL) {
-     check(xsh_flux_calibrate(combeso_frame,res1Deso_frame,frm_atmext,
-			      mresponse_frame,merge_par,instrument,rec_prefix,
-			     &fluxcal_rect_2D_frame,&fluxcal_rect_1D_frame,
-			     &fluxcal_2D_frame,&fluxcal_1D_frame));
-
-  } else if(mresponse_frame == NULL && 
-            (response_frame != NULL && frm_atmext != NULL)) {
+  if (response_frame != NULL && frm_atmext != NULL) {
      check(xsh_flux_calibrate(combeso_frame,res1Deso_frame,frm_atmext,
 			      response_frame,merge_par,instrument,rec_prefix,
 			     &fluxcal_rect_2D_frame,&fluxcal_rect_1D_frame,
@@ -830,7 +816,7 @@ xsh_respon_slit_nod( cpl_parameterlist* parameters,
   check( xsh_add_product_image( combeso_frame, frameset,
                                 parameters, RECIPE_ID, instrument,NULL));
 
-  check( xsh_add_product_image( res1Deso_frame, frameset, parameters,
+  check( xsh_add_product_orders_spectrum( res1Deso_frame, frameset, parameters,
                                 RECIPE_ID, instrument,NULL));
 
   check( xsh_add_product_pre( res2D_frame, frameset, parameters,
@@ -853,7 +839,7 @@ xsh_respon_slit_nod( cpl_parameterlist* parameters,
   if(fluxcal_2D_frame != NULL) {
      check( xsh_add_product_image(fluxcal_rect_2D_frame,frameset,parameters, 
                                   RECIPE_ID, instrument,NULL));
-     check( xsh_add_product_image(fluxcal_rect_1D_frame,frameset,parameters, 
+     check( xsh_add_product_orders_spectrum(fluxcal_rect_1D_frame,frameset,parameters,
                                   RECIPE_ID, instrument,NULL));
 
      check( xsh_add_product_spectrum( fluxcal_2D_frame, frameset, parameters, 
