@@ -107,7 +107,6 @@ Input Frames : \n\
   - A standard star fluxes catalog (Tag = FLUX_STD_CATALOG_arm Type = FLX)\n\
   - A table to set response sampling points (Tag = RESP_FIT_POINTS_CAT_arm)\n\
   - An atmospheric extinction table (Tag = ATMOS_EXT_arm)\n\
-  - [OPTIONAL] An master response curve table (Tag = MRESPONSE_MERGE1D_SLIT_arm)\n\
     if provided this is the one used to flux calibrate the spectra\n\
 Products : \n\
 Products : \n\
@@ -452,7 +451,6 @@ static cpl_error_code
   cpl_frame* std_flux_frame=NULL;
   double exptime=1.;
   cpl_frame* response_frame=NULL;
-  cpl_frame* mresponse_frame=NULL;
   cpl_frame* response_ord_frame=NULL;
 
   //int do_compute_eff = 0 ;
@@ -536,11 +534,6 @@ static cpl_error_code
 
 
   /* QC extra frames */
-  if((mresponse_frame=xsh_find_frame_with_tag(calib,XSH_MRESPONSE_MERGE1D_SLIT,
-                                             instrument)) != NULL ) {
-     xsh_msg("Using the master response curve to flux calibrate the spectrum");
-  }
-
   resp_fit_points_cat_frame=xsh_find_frame_with_tag(calib,XSH_RESP_FIT_POINTS_CAT,instrument);
   if(resp_fit_points_cat_frame==NULL) {
      xsh_msg_warning("Missing input %s_%s response will not be computed",
@@ -841,15 +834,8 @@ static cpl_error_code
 
   }
 
-  if(mresponse_frame != NULL) {
 
-    check(xsh_flux_calibrate(comb_frame_eso,ext_frame_eso,frm_atmext,
-			     mresponse_frame,merge_par,instrument,rec_prefix,
-			     &fluxcal_rect_2D_frame,&fluxcal_rect_1D_frame,
-			     &fluxcal_2D_frame,&fluxcal_1D_frame));
-
-  }
-  else if(mresponse_frame == NULL && response_frame != NULL) {
+  if( response_frame != NULL) {
 
     check(xsh_flux_calibrate(comb_frame_eso,ext_frame_eso,frm_atmext,
 			     response_frame,merge_par,instrument,rec_prefix,
@@ -963,7 +949,7 @@ static cpl_error_code
 				      parameters, RECIPE_ID, instrument));
   */
 
-  check( xsh_add_product_image( ext_frame_eso, frameset,
+  check( xsh_add_product_orders_spectrum( ext_frame_eso, frameset,
 				parameters, RECIPE_ID, instrument,NULL));
 
 
@@ -978,7 +964,7 @@ static cpl_error_code
   if(fluxcal_2D_frame != NULL) {
      check( xsh_add_product_image(fluxcal_rect_2D_frame,frameset,parameters, 
                                   RECIPE_ID, instrument,NULL));
-     check( xsh_add_product_image(fluxcal_rect_1D_frame,frameset,parameters, 
+     check( xsh_add_product_orders_spectrum(fluxcal_rect_1D_frame,frameset,parameters,
                                   RECIPE_ID, instrument,NULL));
      check( xsh_add_product_spectrum( fluxcal_2D_frame, frameset, parameters, 
                                       RECIPE_ID, instrument, NULL));
