@@ -111,7 +111,6 @@ Input Frames : \n\
   - A standard star fluxes catalog (Tag = FLUX_STD_CATALOG_arm Type = FLX)\n\
   - A table to set response sampling points (Tag = RESP_FIT_POINTS_CAT_arm)\n\
   - An atmospheric extinction table (Tag = ATMOS_EXT_arm)\n\
-  - [OPTIONAL] A master response curve table (Tag = MRESPONSE_MERGE1D_SLIT_arm)\n\
     if provided this is the one used to flux calibrate the spectra\n\
 Products : \n\
   - [If STD is in catal] The response ord-by-ord function (Tag = PREFIX_RESPONSE_ORDER1D_SLIT_arm)\n\
@@ -502,7 +501,7 @@ xsh_respon_slit_stare(cpl_parameterlist* parameters,
   cpl_frame * sky_frame_eso = NULL ; /**< Sky spectrum (REC) */
 
   cpl_frame * response_frame = NULL ; /**< computed response frame */
-  cpl_frame * mresponse_frame = NULL ; /**< computed response frame */
+
   cpl_frame * response_ord_frame = NULL ; /**< computed response frame */
   cpl_frame* sky_frame_ima=NULL;
   cpl_frame* clean_obj=NULL;
@@ -564,7 +563,7 @@ xsh_respon_slit_stare(cpl_parameterlist* parameters,
   int merge_par=0;
   xsh_interpolate_bp_param *ipol_bp=NULL;
   int corr_tell=0;
-
+  cpl_frame* sky_orders_chunks =NULL;
   /**************************************************************************/
   /* DFS management */
   /**************************************************************************/
@@ -670,16 +669,11 @@ xsh_respon_slit_stare(cpl_parameterlist* parameters,
   check(xsh_slit_stare_get_calibs(calib,instrument, &spectralformat_frame,
                                   &master_bias,&master_dark,&master_flat,
                                   &order_tab_edges,&model_config_frame,
-                                  &wave_tab,&sky_list_frame,&qc_sky_frame,
+                                  &wave_tab,&sky_list_frame,&sky_orders_chunks,&qc_sky_frame,
                                   &bpmap,&single_frame_sky_sub_tab_frame,
                                   &wavemap_frame,&slitmap_frame,RECIPE_ID,
                                   &recipe_use_model,pre_overscan_corr));
   /* QC extra frames */
-  if((mresponse_frame=xsh_find_frame_with_tag(calib,XSH_MRESPONSE_MERGE1D_SLIT,
-                                             instrument)) != NULL ) {
-     xsh_msg("Using the master response curve to flux calibrate the spectrum");
-  }
-
   resp_fit_points_cat_frame=xsh_find_frame_with_tag(calib,XSH_RESP_FIT_POINTS_CAT,instrument);
   if(resp_fit_points_cat_frame==NULL) {
      xsh_msg_warning("Missing input %s_%s response will not be computed",
@@ -761,7 +755,7 @@ xsh_respon_slit_stare(cpl_parameterlist* parameters,
 
   sprintf(ftag,"%s_STD_NO_CRH_%s",rec_prefix,xsh_instrument_arm_tostring(instrument));
   sprintf(fname,"%s.fits",ftag) ;
-  rm_crh = xsh_remove_crh_single(rmdark,instrument,crh_single_par,ftag) ;
+  rm_crh = xsh_remove_crh_single(rmdark,instrument,NULL,crh_single_par,ftag) ;
   xsh_add_temporary_file(fname);
 
   //xsh_add_temporary_file(cpl_frame_get_filename( rmbias));
@@ -774,13 +768,16 @@ xsh_respon_slit_stare(cpl_parameterlist* parameters,
 
   /* In case CRH single or localize auto do preliminar sky subtraction */
   /* CHECK LEAKS: next call creates small leack */
+  cpl_frame* sky_map_frm = xsh_find_frame_with_tag(calib,XSH_SKY_MAP, instrument);
   check(xsh_slit_stare_correct_crh_and_sky(loc_obj_par,crh_single_par,
                                            rectify_par,
                                            do_sub_sky,rec_prefix,rmbkg,
                                            order_tab_edges, slitmap_frame,
-                                           wavemap_frame,model_config_frame,
+                                           wavemap_frame,sky_map_frm,model_config_frame,
                                            single_frame_sky_sub_tab_frame,
                                            instrument,sub_sky_nbkpts1, sky_par,
+                                           sky_list_frame,
+                                           sky_orders_chunks,
                                            &sky_frame,&sky_frame_eso,
                                            &sky_frame_ima,
                                            wave_tab,disp_tab_frame,
@@ -788,16 +785,32 @@ xsh_respon_slit_stare(cpl_parameterlist* parameters,
                                            &loc_table_frame,&clean_frame,
                                            &clean_obj,1
 ));
-  xsh_free_frame(&rmbkg);
 
+  xsh_free_frame(&rmbkg);
   /* now we divide by the flat for proper sky subtraction */
   check( div_frame = xsh_check_divide_flat( do_flatfield, clean_obj,
     master_flat, instrument, prefix));
   xsh_add_temporary_file(cpl_frame_get_filename(div_frame));
-  check( sub_sky2_frame = xsh_check_subtract_sky_single( do_sub_sky, div_frame,
-      order_tab_edges, slitmap_frame, wavemap_frame, loc_table_frame, NULL,
-      single_frame_sky_sub_tab_frame, instrument, sub_sky_nbkpts2, sky_par,
-      &sky_frame, &sky_frame_eso, &sky_frame_ima, rec_prefix,1));
+  xsh_free_frame(&sky_frame);
+  xsh_free_frame(&sky_frame_eso);
+  xsh_free_frame(&sky_frame_ima);
+  check( sub_sky2_frame = xsh_check_subtract_sky_single( do_sub_sky,
+                                                         div_frame,
+                                                         order_tab_edges,
+                                                         slitmap_frame,
+                                                         wavemap_frame,
+                                                         loc_table_frame,
+                                                         single_frame_sky_sub_tab_frame,
+                                                         instrument,
+                                                         sub_sky_nbkpts2,
+                                                         sky_par,
+                                                         sky_list_frame,
+                                                         sky_orders_chunks,
+                                                         &sky_frame,
+                                                         &sky_frame_eso,
+                                                         &sky_frame_ima,
+                                                         rec_prefix,
+                                                         1));
 
   if(slitmap_frame) {
       xsh_add_temporary_file(cpl_frame_get_filename(slitmap_frame));
@@ -942,23 +955,8 @@ xsh_respon_slit_stare(cpl_parameterlist* parameters,
                                               "RESPONSE","RESP",instrument));
      }
   }
-  if(mresponse_frame != NULL) {
-    check(xsh_flux_calibrate(rect2_frame_eso,ext_frame_eso,frm_atmext,
-			     mresponse_frame,merge_par,instrument,rec_prefix,
-			     &fluxcal_rect_2D_frame,&fluxcal_rect_1D_frame,
-			     &fluxcal_2D_frame,&fluxcal_1D_frame));
 
-    if ( do_optextract){
-
-    check(xsh_flux_calibrate1D(orderoxt1d_eso_frame,frm_atmext,
-			     mresponse_frame,merge_par,instrument,rec_prefix,
-			     &fluxcal_rect_opt1D_frame,
-                             &fluxcal_merg_opt1D_frame));
-
-    }
-
-  }
-  else if(mresponse_frame == NULL && response_frame != NULL) {
+  if( response_frame != NULL) {
 
     check(xsh_flux_calibrate(rect2_frame_eso,ext_frame_eso,frm_atmext,
 			     response_frame,merge_par,instrument,rec_prefix,
@@ -1060,7 +1058,7 @@ xsh_respon_slit_stare(cpl_parameterlist* parameters,
   check( xsh_add_product_image(rect2_frame_eso, frameset, parameters,
 			       RECIPE_ID, instrument,NULL));
 
-  check( xsh_add_product_image(ext_frame_eso, frameset, parameters,
+  check( xsh_add_product_orders_spectrum(ext_frame_eso, frameset, parameters,
 			       RECIPE_ID, instrument,NULL));
 
   check( xsh_add_product_spectrum(res_2D_frame, frameset, parameters, 
@@ -1081,7 +1079,7 @@ xsh_respon_slit_stare(cpl_parameterlist* parameters,
      check( xsh_add_product_image( fluxcal_rect_2D_frame, frameset, parameters, 
                                    RECIPE_ID, instrument,NULL));
  
-    check( xsh_add_product_image( fluxcal_rect_1D_frame, frameset, parameters, 
+    check( xsh_add_product_orders_spectrum( fluxcal_rect_1D_frame, frameset, parameters,
                                   RECIPE_ID, instrument,NULL));
 
      check( xsh_add_product_spectrum( fluxcal_2D_frame, frameset, parameters, 
