@@ -751,7 +751,7 @@ static void xsh_scired_ifu_stare(cpl_parameterlist* parameters,
 				     (void*)NULL) ;
     xsh_msg( "Remove crh (single frame)" ) ;
     check( clean_frame = xsh_remove_crh_single( rmbkg,
-					       instrument,
+					       instrument,NULL,
 					       crh_single_par,
 					       nocrh_tag ) ) ;
     XSH_FREE( nocrh_tag ) ;
