@@ -774,15 +774,15 @@ static void xsh_scired_slit_nod( cpl_parameterlist* parameters,
 
   if(cut_uvb_spectrum) {
       if(instrument->arm == XSH_ARM_UVB) {
-          xsh_image_cut_dichroic_uvb(combeso_frame);
-          xsh_image_cut_dichroic_uvb(res1Deso_frame);
-          xsh_spectrum_cut_dichroic_uvb(res2D_frame);
-          xsh_spectrum_cut_dichroic_uvb(s1D_frame);
+          check(xsh_image_cut_dichroic_uvb(combeso_frame));
+          check(xsh_spectrum_orders_cut_dichroic_uvb(res1Deso_frame,instrument));
+          check(xsh_spectrum_cut_dichroic_uvb(res2D_frame));
+          check(xsh_spectrum_cut_dichroic_uvb(s1D_frame));
           if(fluxcal_rect_2D_frame != NULL) {
-              xsh_image_cut_dichroic_uvb(fluxcal_rect_2D_frame);
-              xsh_image_cut_dichroic_uvb(fluxcal_rect_1D_frame);
-              xsh_spectrum_cut_dichroic_uvb(fluxcal_2D_frame);
-              xsh_spectrum_cut_dichroic_uvb(fluxcal_1D_frame);
+              check(xsh_image_cut_dichroic_uvb(fluxcal_rect_2D_frame));
+              check(xsh_spectrum_orders_cut_dichroic_uvb(fluxcal_rect_1D_frame,instrument));
+              check(xsh_image_cut_dichroic_uvb(fluxcal_2D_frame));
+              check(xsh_spectrum_cut_dichroic_uvb(fluxcal_1D_frame));
           }
       }
   }
@@ -794,7 +794,7 @@ static void xsh_scired_slit_nod( cpl_parameterlist* parameters,
   check( xsh_add_product_image( combeso_frame, frameset,
                                 parameters, RECIPE_ID, instrument,NULL));
 
-  check( xsh_add_product_image( res1Deso_frame, frameset, parameters,
+  check( xsh_add_product_orders_spectrum( res1Deso_frame, frameset, parameters,
                                 RECIPE_ID, instrument,NULL));
 
   check( xsh_add_product_pre( res2D_frame, frameset, parameters,
@@ -817,7 +817,7 @@ static void xsh_scired_slit_nod( cpl_parameterlist* parameters,
   if(fluxcal_2D_frame != NULL) {
      check( xsh_add_product_image(fluxcal_rect_2D_frame,frameset,parameters, 
                                   RECIPE_ID, instrument,NULL));
-     check( xsh_add_product_image(fluxcal_rect_1D_frame,frameset,parameters, 
+     check( xsh_add_product_orders_spectrum(fluxcal_rect_1D_frame,frameset,parameters,
                                   RECIPE_ID, instrument,NULL));
 
      check( xsh_add_product_spectrum( fluxcal_2D_frame, frameset, parameters, 
