@@ -630,9 +630,9 @@ xsh_scired_slit_stare(cpl_parameterlist* parameters,
 				  &recipe_use_model,pre_overscan_corr));
   
   /* scired extra frames */
-  if((response_frame=xsh_find_frame_with_tag(calib,XSH_MRESPONSE_MERGE1D_SLIT,
+  if((response_frame=xsh_find_frame_with_tag(calib,XSH_RESPONSE_MERGE1D_SLIT,
                                              instrument)) == NULL ) {
-  check(response_frame=xsh_find_frame_with_tag(calib,XSH_RESPONSE_MERGE1D_SLIT,
+  check(response_frame=xsh_find_frame_with_tag(calib,XSH_MRESPONSE_MERGE1D_SLIT,
                                                instrument));
   }
   if(response_frame != NULL) {
@@ -790,7 +790,7 @@ xsh_scired_slit_stare(cpl_parameterlist* parameters,
   xsh_slit_stare_correct_crh_and_sky(loc_obj_par,crh_single_par,rectify_par,
                                      do_sub_sky,rec_prefix,rmbkg,
                                      order_tab_edges, slitmap_frame, 
-                                     wavemap_frame,model_config_frame,
+                                     wavemap_frame,sky_map_frm,model_config_frame,
                                      single_frame_sky_sub_tab_frame,instrument,
                                      sub_sky_nbkpts1, sky_par,sky_list_frame,sky_orders_chunks,
                                      &sky_frame,&sky_frame_eso,&sky_frame_ima,
@@ -801,7 +801,9 @@ xsh_scired_slit_stare(cpl_parameterlist* parameters,
   /* now we divide by the flat for proper sky subtraction */
   check( div_frame = xsh_check_divide_flat( do_flatfield, clean_obj,
     master_flat, instrument, rec_prefix));
-
+  xsh_free_frame(&sky_frame);
+  xsh_free_frame(&sky_frame_eso);
+  xsh_free_frame(&sky_frame_ima);
   check( sub_sky2_frame = xsh_check_subtract_sky_single( do_sub_sky,
                                                          div_frame,
                                                          order_tab_edges,
@@ -962,22 +964,23 @@ xsh_scired_slit_stare(cpl_parameterlist* parameters,
   if(cut_uvb_spectrum) {
   if(instrument->arm == XSH_ARM_UVB) {
       xsh_image_cut_dichroic_uvb(rect2_frame_eso);
-      xsh_image_cut_dichroic_uvb(ext_frame_eso);
-      check(xsh_spectrum_cut_dichroic_uvb(res_1D_frame));
-      check(xsh_spectrum_cut_dichroic_uvb(res_2D_frame));
-
+      xsh_spectrum_orders_cut_dichroic_uvb(ext_frame_eso,instrument);
+      xsh_spectrum_cut_dichroic_uvb(res_1D_frame);
+      xsh_spectrum_cut_dichroic_uvb(res_2D_frame);
 
       if(res_2D_sky_frame) {
           xsh_spectrum_cut_dichroic_uvb(res_2D_sky_frame);
           xsh_spectrum_cut_dichroic_uvb(res_1D_sky_frame);
       }
+
       if ( do_optextract){
           xsh_spectrum_cut_dichroic_uvb(mergeext1d_frame);
           xsh_spectrum_cut_dichroic_uvb(mergeoxt1d_frame);
       }
+
       if(fluxcal_rect_2D_frame != NULL) {
           xsh_image_cut_dichroic_uvb(fluxcal_rect_2D_frame);
-          xsh_image_cut_dichroic_uvb(fluxcal_rect_1D_frame);
+          xsh_spectrum_orders_cut_dichroic_uvb(fluxcal_rect_1D_frame,instrument);
           xsh_spectrum_cut_dichroic_uvb(fluxcal_2D_frame);
           xsh_spectrum_cut_dichroic_uvb(fluxcal_1D_frame);
           if ( do_optextract){
@@ -989,7 +992,8 @@ xsh_scired_slit_stare(cpl_parameterlist* parameters,
 
   }
   }
-  check(xsh_monitor_spectrum1D_flux(res_1D_frame,instrument));
+  xsh_monitor_spectrum1D_flux(res_1D_frame,instrument);
+
   /* saving products */   
 
   xsh_msg( "Save products" ) ;
@@ -998,9 +1002,8 @@ xsh_scired_slit_stare(cpl_parameterlist* parameters,
   sprintf(prefix,"%s_ORDER2D",rec_prefix);
   check( xsh_add_product_image(rect2_frame_eso, frameset, parameters,
 			       RECIPE_ID, instrument,prefix));
-
-  check( xsh_add_product_image(ext_frame_eso, frameset, parameters,
-			       RECIPE_ID, instrument,NULL));
+  xsh_add_product_orders_spectrum(ext_frame_eso, frameset, parameters,
+			       RECIPE_ID, instrument,NULL);
 
   check( xsh_add_product_spectrum( res_2D_frame, frameset, parameters, 
 				   RECIPE_ID, instrument, NULL));
@@ -1064,7 +1067,7 @@ xsh_scired_slit_stare(cpl_parameterlist* parameters,
 				RECIPE_ID, instrument));
     check( xsh_add_product_image( sky_frame_ima, frameset, parameters,
 				  RECIPE_ID, instrument,NULL));
-    check( xsh_add_product_image( sky_frame_eso, frameset,
+    check( xsh_add_product_orders_spectrum( sky_frame_eso, frameset,
                                   parameters, RECIPE_ID, instrument,NULL));
   }
   if(frame_backg != NULL) {
@@ -1087,8 +1090,8 @@ xsh_scired_slit_stare(cpl_parameterlist* parameters,
   if(fluxcal_rect_2D_frame != NULL) {
      check( xsh_add_product_image( fluxcal_rect_2D_frame, frameset, parameters, 
                                    RECIPE_ID, instrument,NULL));
- 
-     check( xsh_add_product_image( fluxcal_rect_1D_frame, frameset, parameters, 
+
+     check( xsh_add_product_orders_spectrum( fluxcal_rect_1D_frame, frameset, parameters,
                                    RECIPE_ID, instrument,NULL));
 
      check( xsh_add_product_spectrum( fluxcal_2D_frame, frameset, parameters, 
