@@ -733,8 +733,8 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
   check( sub_frameset = xsh_subtract_sky_offset( crh_clean_obj, crh_clean_sky,
 						 nb_sub_frames, instrument)) ;
 
-
-
+  xsh_free_frameset(&crh_clean_obj);
+  xsh_free_frameset(&crh_clean_sky);
 
   /**************************************************************************/
   /* Check that SCI IFU frame and AFC corrected CFG are proper              */
@@ -895,6 +895,8 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
     XSH_FREE( rectify_par ) ;
     XSH_FREE(stack_par);
     xsh_instrument_free(&instrument );
+    xsh_free_frame(&wavemap);
+    xsh_free_frame(&slitmap);
     xsh_free_frameset(&ext_frameset_images);
     xsh_free_frameset(&rect2_frameset_tables);
     xsh_free_frameset(&ext_frameset_tables);
