@@ -2,7 +2,11 @@
 try:
 #  import sys
   import numpy
-  import pyfits
+  try:
+    from astropy.io import fits as pyfits
+  except:
+    import pyfits
+
   import xsh_parameters_common
 #  import wx
 #  import matplotlib
@@ -123,7 +127,8 @@ try:
 
           self.oplotImageScatter(img_disp,tab,ext,binx,biny,Xcol1,Ycol1,subplot, 'o', 10, 'green' )
 
-          img_disp.display(subplot, title, self.paragraph(tooltip),obj.image,bpm.image)
+          bpm_filt = ( (bpm.image.astype(int) & self.decode_bp) != 0 )
+          img_disp.display(subplot, title, self.paragraph(tooltip),obj.image,bpm_filt)
           #as the scatter display add extra space round the image (not
           #to have points at edges) we force the bounds of the scatter
           #plot to be the same as the image size.
@@ -140,7 +145,8 @@ try:
           self.oplotImageScatter(img_disp,tab,ext,binx,biny,Xcol1,Ycol1,subplot, 'o', 10, 'blue' )
           self.oplotImageScatter(img_disp,tab,ext,binx,biny,Xcol2,Ycol2,subplot, 'o', 10, 'yellow' )
 
-          img_disp.display(subplot, title, self.paragraph(tooltip),obj.image,bpm.image)
+          bpm_filt = ( (bpm.image.astype(int) & self.decode_bp) != 0 )
+          img_disp.display(subplot, title, self.paragraph(tooltip),obj.image,bpm_filt)
           #as the scatter display add extra space round the image (not
           #to have points at edges) we force the bounds of the scatter
           #plot to be the same as the image size.
@@ -161,8 +167,8 @@ try:
 
 #          self.img_obj.setXLinearWCSAxis(img_obj.crval1,img_obj.cdelt1,img_obj.crpix1)
 
-         
-          img_disp.display(subplot, title,self.paragraph(tooltip),obj.image,bpm.image)
+          bpm_filt = ( (bpm.image.astype(int) & self.decode_bp) != 0 )
+          img_disp.display(subplot, title,self.paragraph(tooltip),obj.image,bpm_filt)
           #as the scatter display add extra space round the image (not
           #to have points at edges) we force the bounds of the scatter
           #plot to be the same as the image size.
@@ -435,7 +441,8 @@ try:
          self.rec_subtitle = "Master Flat Creation. "
       if self.rec_id == "xsh_2dmap":
          self.rec_subtitle = "2D Geometry. "
-
+      self.decode_bp = int(hdulist[0].header['ESO PRO REC1 PARAM4 VALUE'])
+      
     # This function creates all the subplots. It is responsible for the plotting 
     # layouts. 
     # There can different layouts, depending on the availability of data
