@@ -2,7 +2,11 @@
 try:
 #  import sys
   import numpy
-  import pyfits
+  try:
+    from astropy.io import fits as pyfits
+  except:
+    import pyfits
+
   import wx
   import matplotlib
   import pipeline_product
@@ -124,7 +128,12 @@ try:
 
 	  #img_obj.setLimits((0,x_size),(0,y_size))
           #print bpm.image
-          bpm_filt = ( (bpm.image & self.decode_bp) != 0 )
+          bp_code_missing_data = 524288
+          bp_code_sky_model_inaccurate = 8388608
+          bp_code_sky_model_outliers = 16777216
+          bp_code_display = self.decode_bp - bp_code_sky_model_inaccurate - bp_code_sky_model_outliers
+          bpm_filt = ( (bpm.image & bp_code_display ) != 0 )  
+          #bpm_filt = ( (bpm.image & self.decode_bp ) != 0 )  
           #my_image = bpm.image 
           img_obj.display(subplot, title, self.paragraph(tooltip),obj.image,bpm_filt)
           if self.response_found is True and self.rec_id[16:19] != "nod":
@@ -575,6 +584,8 @@ try:
            self.plotSpectrum(self.flux_spectrum1D,self.flux_error1D,self.flux_qual1D,self.decode_bp,self.subplot_flux_spectrum,title_flux_spectrum,tooltip_flux_spectrum)
         if self.response_found == True :
            self.oplotTable(self.response,'LAMBDA','REF','Wavelength [nm]','Reference flux [erg/e-/cm^2]',self.subplot_flux_spectrum,'green')
+        if self.mresponse_found == True :
+           self.oplotTable(self.response,'LAMBDA','REF','Wavelength [nm]','Reference flux [erg/e-/cm^2]',self.subplot_flux_spectrum,'yellow')
 
 
 
