@@ -2,7 +2,11 @@
 try:
 #  import sys
   import numpy
-  import pyfits
+  try:
+    from astropy.io import fits as pyfits
+  except:
+    import pyfits
+
   import wx
   import matplotlib
   import pipeline_product
