@@ -61,6 +61,27 @@
 /*---------------------------------------------------------------------------
   Defines
   ---------------------------------------------------------------------------*/
+/*----------------------------------------------------------------------------*/
+/**
+ * AMO added (useful in unit tests)
+  @brief    generates random data with Poisson distribution
+  @param    expectedValue random generator goal value
+  @return   random value
+ */
+/*----------------------------------------------------------------------------*/
+static int xsh_poisson_random(double expectedValue) {
+    int n = 0; //counter of iteration
+    double limit;
+    double x;  //pseudo random number
+    limit = exp(-expectedValue);
+    x = (double)rand() / (double)INT_MAX;
+    while (x > limit) {
+      n++;
+      x *= (double)rand() / (double)INT_MAX;
+    }
+    return n;
+  }
+
 
 /*---------------------------------------------------------------------------
   Functions implementation
@@ -103,7 +124,9 @@ cpl_frame* xsh_test_create_frame(const char* name,int nx, int ny,
   cpl_propertylist *header = NULL;
   cpl_image *data = NULL;
   cpl_frame *frame = NULL;
-
+  float* pdata=NULL;
+  int size=nx*ny;
+  int i,j;
   XSH_ASSURE_NOT_NULL( instrument);
   XSH_ASSURE_NOT_NULL( name);
 
@@ -118,9 +141,14 @@ cpl_frame* xsh_test_create_frame(const char* name,int nx, int ny,
 			  50,     /* norm */
 			  nx, ny / 8.0); /* sigma */
 
+  /* add random noise, centered at 100 */
+  pdata=cpl_image_get_data_float(data);
+  for(j=0;j<size;j++) {
+      pdata[j]+=xsh_poisson_random(100.);
+  }
   check( cpl_image_save(data, name, XSH_PRE_DATA_BPP,header,
     CPL_IO_DEFAULT));
-
+ 
   /* Create test frame */
   frame = cpl_frame_new();
   cpl_frame_set_filename(frame,name);
