@@ -651,6 +651,34 @@ void xsh_bpmap_collapse_mean(cpl_image * mean, cpl_imagelist * list,
     return;
 }
 
+/**
+ * Create In the rare case input image has some flagged pixel flag them in the
+ * qual
+ *
+ * @param qual input pixel quality image
+ * @param image input image (with possibly flagged pixels)
+ */
+cpl_error_code
+xsh_badpixel_flag_rejected(cpl_image* qual, cpl_image* image)
+{
+
+    int nx = cpl_image_get_size_x(qual);
+    int ny = cpl_image_get_size_y(qual);
+    int* pqual=cpl_image_get_data_int(qual);
+    cpl_mask* bpm=cpl_image_get_bpm(image);
+    int* pbpm=cpl_mask_get_data(bpm);
+    //xsh_msg("Bitwise OR combine");
+    for(int j=0;j<ny;j++) {
+        int j_nx=j*nx;
+        for(int i=0;i<nx;i++) {
+            if( pbpm[j_nx+i] == CPL_BINARY_1 ) {
+
+                pqual[j_nx+i] |= QFLAG_ALL_PIX_BAD;
+            }
+        }
+    }
+    return cpl_error_get_code();
+}
 
 /** 
  * Create coadd a mask frame with another 
@@ -1372,60 +1400,78 @@ xsh_count_satpix(xsh_pre* pre, xsh_instrument* instr,const int datancom)
 }
 
 cpl_error_code
-xsh_badpixelmap_flag_saturated_pixels(xsh_pre* pre,xsh_instrument* instr,const double cor_val, int flag, int* nsat)
+xsh_badpixelmap_flag_saturated_pixels(xsh_pre* pre,xsh_instrument* instr,
+                                      const double cor_val, int flag, int* nsat)
 {
-  int size=0;
-  int i=0;
-  float* pima=NULL;
-  int* pqual=NULL;
-  int bp_code_sat=0;
-  int bp_code_neg=0;
-  double thresh_max=0;
-  //double time=0;
-  float cpima=0;
+    int size=0;
+    int i=0;
+    float* pima=NULL;
+    int* pqual=NULL;
+    int bp_code_sat=0;
+    int bp_code_neg=0;
+    double thresh_max=0;
+    //double time=0;
+    float cpima=0;
 
-  XSH_ASSURE_NOT_NULL_MSG(pre, "Null input pre frame");
-  XSH_ASSURE_NOT_NULL_MSG(instr, "Null input pre frame");
-  size=pre->nx*pre->ny;
-  /* define thresholds and corresponding codes */
-  bp_code_sat=QFLAG_ADC_SATURATION;
-  bp_code_neg=QFLAG_NEGATIVE_DATA;
-  if(xsh_instrument_get_arm(instr) != XSH_ARM_NIR) {
-     thresh_max=65000;
-  } else {
-     thresh_max=42000;
-     bp_code_sat=QFLAG_SATURATED_DATA;
-  }
-
-  check(pima=cpl_image_get_data_float(pre->data));
-  check(pqual=cpl_image_get_data_int(pre->qual));
-
-  /* if the frame was overscan corrected we correct the threshold */
-  thresh_max=thresh_max -cor_val;
-
-  if(flag) {
-    double thresh_min=1-cor_val;
-    for(i=0;i<size;i++) {
-      cpima=pima[i];
-      //xsh_msg("ima val=%g",cpima);
-      if( pima[i] > thresh_max) {
-	pqual[i] |= bp_code_sat;
-	(*nsat)++;
-      } 
-      if  ( cpima < thresh_min  ) {
-	pqual[i] |= bp_code_neg;
-      }
+    XSH_ASSURE_NOT_NULL_MSG(pre, "Null input pre frame");
+    XSH_ASSURE_NOT_NULL_MSG(instr, "Null input pre frame");
+    size=pre->nx*pre->ny;
+    /* define thresholds and corresponding codes */
+    bp_code_sat=QFLAG_ADC_SATURATION;
+    bp_code_neg=QFLAG_NEGATIVE_DATA;
+    if(xsh_instrument_get_arm(instr) != XSH_ARM_NIR) {
+        thresh_max=65000;
+    } else {
+        thresh_max=42000;
+        bp_code_sat=QFLAG_SATURATED_DATA;
     }
-  } else {
-    for(i=0;i<size;i++) {
-      if( pima[i] > thresh_max) {
-	(*nsat)++;
-      } 
-    }
-  }
 
-  cleanup:
-  return cpl_error_get_code();
+    check(pima=cpl_image_get_data_float(pre->data));
+    check(pqual=cpl_image_get_data_int(pre->qual));
+    int nx=pre->nx;
+    int ny=pre->ny;
+    int ipix=0;
+    int j=0;
+    int jnx=0;
+    //xsh_msg("nx=%d ny=%d",nx,ny);
+
+    /* if the frame was overscan corrected we correct the threshold */
+    thresh_max=thresh_max -cor_val;
+    /* position of bottom left edge of NIR frame corresponding to K band */
+    int knx=758;
+    if(flag) {
+        double thresh_min=1-cor_val;
+        for(j=0;j<ny;j++) {
+            jnx=j*nx;
+            for(i=0;i<knx;i++) {
+                ipix=i+jnx;
+                //for(ipix=0;ipix<size;ipix++) {
+                cpima=pima[ipix];
+                //xsh_msg("ima val=%g",cpima);
+                if( pima[ipix] > thresh_max) {
+                    pqual[ipix] |= bp_code_sat;
+                    (*nsat)++;
+                }
+                if  ( cpima < thresh_min  ) {
+                    pqual[ipix] |= bp_code_neg;
+                }
+            }
+        }
+    } else {
+        for(j=0;j<ny;j++) {
+            jnx=j*nx;
+            for(i=0;i<knx;i++) {
+                ipix=i+jnx;
+                if( pima[ipix] > thresh_max) {
+                    (*nsat)++;
+                }
+            }
+        }
+    }
+
+
+    cleanup:
+    return cpl_error_get_code();
 }
 
 cpl_error_code
