@@ -736,7 +736,7 @@ xsh_create_master_dark2(cpl_frameset * raws,
 
   sprintf(mdark_tag,"%s_%s",XSH_MASTER_DARK,xsh_instrument_arm_tostring(instr));
   sprintf(mdark_name,"%s.fits",mdark_tag);
-
+  xsh_count_satpix(pre,instr,sz);
   check(mdark = xsh_pre_save( pre,mdark_name,mdark_tag,0));
   check(cpl_frame_set_tag(mdark,mdark_tag));
 
@@ -1322,12 +1322,13 @@ xsh_compute_qc_on_master_bias (cpl_frameset* raws,
   char mastername[256];
   //int binx=0;
   //int biny=0;
+  int nraws =0;
 
   XSH_ASSURE_NOT_NULL(frame);
   check(master = xsh_pre_load (frame,instr));
   /* set the PROCATG KW */
   check(xsh_pfits_set_pcatg (master->data_header, tag));
-
+  
   //check(binx=xsh_pfits_get_binx(master->data_header));
   //check(biny=xsh_pfits_get_biny(master->data_header));
 
@@ -1342,7 +1343,12 @@ xsh_compute_qc_on_master_bias (cpl_frameset* raws,
   sprintf(mastername,"MASTER_BIAS_%s.fits", 
 			  xsh_instrument_arm_tostring (instr));
 
+  nraws = cpl_frameset_get_size(raws);
+  xsh_msg("nraws=%d",nraws);
+  xsh_count_satpix(master, instr, nraws);
+
   xsh_msg ("Create master bias");
+
   check(masterFrame = xsh_pre_save (master, mastername,tag,0 ));
   cpl_frame_set_tag (masterFrame, tag);
   cpl_frame_set_group(masterFrame,CPL_FRAME_GROUP_CALIB);
@@ -1441,7 +1447,7 @@ xsh_create_master_flat_with_mask (cpl_frame *frame, cpl_frame* edges, xsh_instru
   XSH_FREE( name);
   XSH_NAME_LAMP_MODE_ARM( name, "MASTER_FLAT",".fits",instr);
   xsh_msg ("Create master flat %s tag %s", name, tag);
-
+ 
   check( masterFrame = xsh_pre_save( master, name, tag,0));
   check( cpl_frame_set_tag( masterFrame, tag));
   check( cpl_frame_set_group( masterFrame, CPL_FRAME_GROUP_CALIB));
@@ -2359,7 +2365,7 @@ xsh_create_master_flat2(cpl_frameset *set,
     sprintf(mflat_tag, "%s_%s", XSH_MASTER_FLAT,xsh_instrument_arm_tostring(inst));
   }
   sprintf(mflat_name,"%s.fits",mflat_tag);
-
+  xsh_count_satpix(pre, inst,size);
   check(mflat = xsh_pre_save( pre,mflat_name,mflat_tag,1));
   check(cpl_frame_set_tag(mflat,mflat_tag));
 
