@@ -285,98 +285,7 @@ xsh_rec_list * xsh_rec_list_duplicate( xsh_rec_list * old,
 
 */
 /*---------------------------------------------------------------------------*/
-#if 0
-xsh_rec_list* xsh_rec_list_load(cpl_frame* frame,
-				xsh_instrument* instrument)
-{
-  xsh_rec_list* result = NULL;
-  const char * tablename = NULL ;
-  const cpl_table * table = NULL; 
-  cpl_propertylist* header = NULL;
-  int max_nlambda = 0, max_nslit = 0 ;
-  int i ;
 
-  /* check input parameters */
-  XSH_ASSURE_NOT_NULL(frame);
-  XSH_ASSURE_NOT_NULL(instrument);
-
-  /* get table filename */
-  check(tablename = cpl_frame_get_filename(frame));
-  xsh_msg_dbg_low( "Rectified Frame: %s", tablename ) ;
-
-  /* Load table */
-  XSH_TABLE_LOAD( table, tablename);
-
-  check(result = xsh_rec_list_create(instrument));
-
-  check(header = cpl_propertylist_load(tablename,0));
-  check(cpl_propertylist_append(result->header, header));
-  
-  XSH_ASSURE_NOT_ILLEGAL(result->size == cpl_table_get_nrow(table));
-
-  for(i=0;i<result->size;i++) {
-    int nb, k, order, depth, nlambda, nslit ;
-    const cpl_array * data_array ;
-    const float * farray = NULL ;
-    const int * iarray = NULL ;
-
-    /* Get order, nlambda, nslit */
-    check(xsh_get_table_value(table, XSH_REC_TABLE_COLNAME_ORDER,
-			      CPL_TYPE_INT, i, &order));
-    result->list[i].order = order ;
-    check(xsh_get_table_value(table, XSH_REC_TABLE_COLNAME_NLAMBDA,
-			      CPL_TYPE_INT, i, &nlambda ));
-    result->list[i].nlambda = nlambda ;
-    check(xsh_get_table_value(table, XSH_REC_TABLE_COLNAME_NSLIT,
-			      CPL_TYPE_INT, i, &nslit ));
-    result->list[i].nslit = nslit ;
-    if ( nslit > max_nslit ) max_nslit = nslit ;
-    if ( nlambda > max_nlambda ) max_nlambda = nlambda ;
-
-    xsh_msg_dbg_high( "Order %d (%d): nslt = %d, nlambda = %d", i, order,
-		      nslit, nlambda ) ;
-    /* Get arrays (flux, errs, qual ) */
-    xsh_rec_list_set_data_size( result, i, order, nlambda, nslit ) ;
-    depth = nlambda*nslit ;
-
-    check( data_array = cpl_table_get_array( table,
-					     XSH_REC_TABLE_COLNAME_FLUX1,
-					     i )) ;
-    nb = cpl_array_get_size( data_array ) ;
-    XSH_ASSURE_NOT_ILLEGAL( nb >= depth ) ;
-
-    /* Copy data to rec_list */
-    check( farray = cpl_array_get_data_float_const( data_array ) ) ;
-    for( k = 0 ; k<depth ; k++ ) *(result->list[i].data1+k) = *farray++ ;
-
-    farray = NULL ;
-    check( data_array = cpl_table_get_array( table,
-					     XSH_REC_TABLE_COLNAME_ERRS1,
-					     i )) ;
-    check( nb = cpl_array_get_size( data_array ) ) ;
-    /* Copy data to rec_list */
-    check( farray = cpl_array_get_data_float_const( data_array ) ) ;
-    for( k = 0 ; k<depth ; k++ ) *(result->list[i].errs1+k) = *farray++ ;
-
-    check( data_array = cpl_table_get_array( table,
-					     XSH_REC_TABLE_COLNAME_QUAL1,
-					     i )) ;
-    nb = cpl_array_get_size( data_array ) ;
-    /* Copy data to rec_list */
-    iarray = cpl_array_get_data_int_const( data_array ) ;
-    for( k = 0 ; k<depth ; k++ ) *(result->list[i].qual1+k) = *iarray++ ;
-
-  }
-  xsh_msg_dbg_high( "Max Lambda: %d, Max Slit: %d", max_nlambda, max_nslit ) ;
-
-  result->max_nlambda = max_nlambda ;
-  result->max_nslit = max_nslit ;
-
-
- cleanup:
-  return result; 
-}
-#else
 xsh_rec_list* xsh_rec_list_load(cpl_frame* frame,
 				xsh_instrument* instrument)
 {
@@ -492,7 +401,7 @@ xsh_rec_list* xsh_rec_list_load(cpl_frame* frame,
   xsh_free_propertylist(&header);
   return result ;
 }
-#endif
+
 
 
 xsh_rec_list* xsh_rec_list_load_eso(cpl_frame* frame,
@@ -651,6 +560,139 @@ xsh_rec_list* xsh_rec_list_load_eso(cpl_frame* frame,
 }
 
 
+xsh_rec_list* xsh_rec_list_load_eso_1d(cpl_frame* frame,
+                    xsh_instrument* instrument)
+{
+  xsh_rec_list* result = NULL;
+  const char * imagelist_name = NULL ;
+  cpl_vector * vec_data = NULL;
+  cpl_vector * vec_errs = NULL;
+  cpl_vector * vec_qual = NULL;
+  cpl_propertylist* header = NULL;
+  cpl_propertylist* hdata=NULL;
+  cpl_propertylist* herrs=NULL;
+  cpl_propertylist* hqual=NULL;
+  const char* ext_name=NULL;
+
+  int nbext, i,j ;
+  int size;
+
+  /* check input parameters */
+  XSH_ASSURE_NOT_NULL(frame);
+  XSH_ASSURE_NOT_NULL(instrument);
+
+
+  /* get table filename */
+  check(imagelist_name = cpl_frame_get_filename(frame));
+  xsh_msg_dbg_low( "Loading Rectified Frame: %s", imagelist_name ) ;
+
+  check( nbext = cpl_frame_get_nextensions( frame));
+
+
+  size=(nbext+1)/3;
+
+  /* Create internal structure */
+  /* Allocate memory */
+  XSH_CALLOC(result, xsh_rec_list, 1);
+  result->size = size;
+  XSH_ASSURE_NOT_ILLEGAL(result->size > 0);
+  result->instrument = instrument;
+
+  XSH_CALLOC( result->list, xsh_rec, result->size);
+
+  XSH_NEW_PROPERTYLIST( result->header);
+
+
+  check(header = cpl_propertylist_load(imagelist_name,0));
+  check(cpl_propertylist_erase_regexp(header,
+                        "^(ARCFILE|ORIGFILE|CHECKSUM|DATASUM)$", CPL_FALSE));
+  check(cpl_propertylist_append(result->header, header));
+
+  xsh_free_propertylist(&header);
+
+  //nbext = size;
+
+  xsh_msg_dbg_medium( "   Nb of extensions: %d", nbext ) ;
+  /* Loop over FITS extensions */
+
+  for( i = 0,j=0 ; j<nbext ; i++, j+=3 ) {
+    int k, order, depth, nlambda;
+    const double * farray = NULL ;
+    const double * iarray = NULL ;
+    double w_step=0;
+    double w_start=0;
+    int sx=0;
+
+    check(vec_data=cpl_vector_load(imagelist_name,j+0));
+    check(vec_errs=cpl_vector_load(imagelist_name,j+1));
+    check(vec_qual=cpl_vector_load(imagelist_name,j+2));
+
+    check( hdata = cpl_propertylist_load( imagelist_name, j+0 ) ) ;
+    check( herrs = cpl_propertylist_load( imagelist_name, j+1 ) ) ;
+    check( hqual = cpl_propertylist_load( imagelist_name, j+2 ) ) ;
+    check(ext_name=xsh_pfits_get_extname(herrs));
+    order=10*(ext_name[3]-48)+(ext_name[4]-48);
+    //xsh_msg("iter=%d order=%d",i,order);
+
+    /* Now populate the structure */
+    result->list[i].order = order ;
+
+    nlambda=xsh_pfits_get_naxis1(herrs);
+
+    w_step=xsh_pfits_get_cdelt1(herrs);
+
+    w_start=xsh_pfits_get_crval1(herrs);
+
+    result->list[i].nlambda = nlambda ;
+
+    xsh_rec_list_set_data_size( result, i, order, nlambda, 1 ) ;
+
+    /* Get arrays (lambda) */
+    for(k=0;k<nlambda;k++) {
+      *(result->list[i].lambda+k)=(w_start+k*w_step);
+    }
+    /* Get arrays (flux, errs, qual ) */
+    depth = nlambda;
+
+    /* Copy FLUX1 data to rec_list */
+    check( farray = cpl_vector_get_data( vec_data)) ;
+    sx = cpl_vector_get_size( vec_data ) ;
+    XSH_ASSURE_NOT_ILLEGAL( sx == depth ) ;
+
+    for( k = 0 ; k<depth ; k++ ) *(result->list[i].data1+k) = (float)*farray++ ;
+    farray = NULL ;
+
+    /* Copy ERRS1 data to rec_list */
+    check( farray = cpl_vector_get_data( vec_errs)) ;
+    for( k = 0 ; k<depth ; k++ ) *(result->list[i].errs1+k) = (float)*farray++ ;
+
+    /* Copy QUAL1 data to rec_list */
+    check( iarray = cpl_vector_get_data( vec_qual)) ;
+    for( k = 0 ; k<depth ; k++ ) *(result->list[i].qual1+k) = (int)*iarray++ ;
+
+    xsh_msg_dbg_low( "   Loaded, order %d, nlambda %d",order, nlambda) ;
+
+    xsh_free_vector( &vec_data ) ;
+    xsh_free_vector( &vec_errs ) ;
+    xsh_free_vector( &vec_qual ) ;
+    xsh_free_propertylist( &hdata ) ;
+    xsh_free_propertylist( &herrs ) ;
+    xsh_free_propertylist( &hqual ) ;
+
+  }
+
+ cleanup:
+  xsh_free_vector( &vec_data ) ;
+  xsh_free_vector( &vec_errs ) ;
+  xsh_free_vector( &vec_qual ) ;
+  xsh_free_propertylist( &hdata ) ;
+  xsh_free_propertylist( &herrs ) ;
+  xsh_free_propertylist( &hqual ) ;
+
+  xsh_free_propertylist(&header);
+
+  return result ;
+}
 
 
 /*---------------------------------------------------------------------------*/
@@ -1518,20 +1560,35 @@ xsh_rec_list_save2(xsh_rec_list* list,const char* filename, const char* tag)
     if ( nslit > 1){
       xsh_msg_dbg_high("nslit %d", nslit);
       cdelt2=pslit[1]-pslit[0];
-    } else {
-      cdelt2=1;
-    }
+      xsh_pfits_set_wcs(header_data,crpix1,crval1,cdelt1,crpix2,crval2,cdelt2);
+      xsh_pfits_set_wcs(header_errs,crpix1,crval1,cdelt1,crpix2,crval2,cdelt2);
+      xsh_pfits_set_wcs(header_qual,crpix1,crval1,cdelt1,crpix2,crval2,cdelt2);
 
-    xsh_pfits_set_wcs(header_data,crpix1,crval1,cdelt1,crpix2,crval2,cdelt2);
+    } else {
+      cpl_propertylist_erase_regexp(header_data, "^CRPIX2",0);
+      cpl_propertylist_erase_regexp(header_data, "^CRVAL2",0);
+      cpl_propertylist_erase_regexp(header_data, "^CDELT2",0);
+
+      cpl_propertylist_erase_regexp(header_errs, "^CRPIX2",0);
+      cpl_propertylist_erase_regexp(header_errs, "^CRVAL2",0);
+      cpl_propertylist_erase_regexp(header_errs, "^CDELT2",0);
+
+      cpl_propertylist_erase_regexp(header_qual, "^CRPIX2",0);
+      cpl_propertylist_erase_regexp(header_qual, "^CRVAL2",0);
+      cpl_propertylist_erase_regexp(header_qual, "^CDELT2",0);
+
+      xsh_pfits_set_wcs1(header_data, crpix1, crval1, cdelt1);
+      xsh_pfits_set_wcs1(header_errs, crpix1, crval1, cdelt1);
+      xsh_pfits_set_wcs1(header_qual, crpix1, crval1, cdelt1);
+  
+    }
+    
     xsh_pfits_set_extract_slit_min( header_data,list->slit_min);
     xsh_pfits_set_extract_slit_max( header_data,list->slit_max);
 
-
-    xsh_pfits_set_wcs(header_errs,crpix1,crval1,cdelt1,crpix2,crval2,cdelt2);
     xsh_pfits_set_extract_slit_min( header_errs,list->slit_min);
     xsh_pfits_set_extract_slit_max( header_errs,list->slit_max);
 
-    xsh_pfits_set_wcs(header_qual,crpix1,crval1,cdelt1,crpix2,crval2,cdelt2);
     xsh_pfits_set_extract_slit_min( header_qual,list->slit_min);
     xsh_pfits_set_extract_slit_max( header_qual,list->slit_max);
     
@@ -1545,28 +1602,47 @@ xsh_rec_list_save2(xsh_rec_list* list,const char* filename, const char* tag)
     check(xsh_plist_set_extra_keys(header_data,"IMAGE","DATA","RMSE",
                                    data_extname,errs_extname,qual_extname,0));
 
-    check(cpl_image_save(img_flux,filename, CPL_BPP_IEEE_FLOAT, 
-			   header_data, mode));
-
 
     xsh_pfits_set_bunit(header_errs,XSH_BUNIT_FLUX_REL_C);
     xsh_pfits_set_extname( header_errs, errs_extname);
     check(xsh_plist_set_extra_keys(header_errs,"IMAGE","DATA","RMSE",
                                    data_extname,errs_extname,qual_extname,1));
 
-    check(cpl_image_save(img_err,filename, CPL_BPP_IEEE_FLOAT, 
-			   header_errs, CPL_IO_EXTEND)) ;
- 
-
     xsh_pfits_set_bunit(header_qual,XSH_BUNIT_NONE_C);
     xsh_pfits_set_extname( header_qual,qual_extname);
     check(xsh_plist_set_extra_keys(header_qual,"IMAGE","DATA","RMSE",
                                    data_extname,errs_extname,qual_extname,2));
 
-    check(cpl_image_save(img_qual, filename, XSH_PRE_QUAL_BPP, 
-			   header_qual, CPL_IO_EXTEND)) ;
-
     mode = CPL_IO_EXTEND;
+    if ( nslit > 1){
+       if(i==0) {
+          cpl_image_save(img_flux,filename, CPL_BPP_IEEE_FLOAT, header_data, 
+                         CPL_IO_DEFAULT);
+       } else {
+          cpl_image_save(img_flux,filename, CPL_BPP_IEEE_FLOAT, header_data, mode);
+
+       }
+       cpl_image_save(img_err,filename, CPL_BPP_IEEE_FLOAT, header_errs, mode) ;
+       cpl_image_save(img_qual, filename, XSH_PRE_QUAL_BPP, header_qual, mode) ;
+
+    } else {
+      cpl_vector* flux1D = cpl_vector_new_from_image_row( img_flux, 1);
+      cpl_vector* errs1D = cpl_vector_new_from_image_row( img_err, 1);
+      cpl_vector* qual1D = cpl_vector_new_from_image_row( img_qual, 1);
+
+       if(i==0) {
+          cpl_vector_save( flux1D, filename, CPL_BPP_IEEE_FLOAT, header_data,CPL_IO_DEFAULT );
+       } else {
+          cpl_vector_save( flux1D, filename, CPL_BPP_IEEE_FLOAT, header_data, mode);
+       }
+      cpl_vector_save( errs1D, filename, CPL_BPP_IEEE_FLOAT, header_errs, mode);
+      cpl_vector_save( qual1D, filename, CPL_BPP_32_SIGNED, header_qual, mode);
+      xsh_free_vector( &flux1D);
+      xsh_free_vector( &errs1D);
+      xsh_free_vector( &qual1D);
+    }
+
+ 
 
     xsh_free_image(&img_lambda);
     xsh_free_image(&img_slit);
