@@ -792,7 +792,7 @@ cpl_frame* xsh_spectrum_save_order( xsh_spectrum* s, const char* filename,
                                 s->flux_header, CPL_IO_DEFAULT));
      } else {
         check( cpl_vector_save( flux1D, filename, XSH_SPECTRUM_DATA_BPP, 
-                                s->flux_header, CPL_IO_DEFAULT));
+                                s->flux_header, CPL_IO_EXTEND));
      }
      check( cpl_vector_save( err1D, filename, XSH_SPECTRUM_ERRS_BPP,
                              s->errs_header, CPL_IO_EXTEND));
@@ -870,6 +870,7 @@ xsh_spectrum_extract_range( xsh_spectrum * org, const double wmin,const double w
   result->slit_max = org->slit_max;
   result->size_slit = org->size_slit ;
   check(result->size = size_x);
+  /*
   xsh_msg("size_lambda=%d",org->size_lambda);
   xsh_msg("size_slit=%d",org->size_slit);
   xsh_msg("slit_min=%g",org->slit_min);
@@ -881,10 +882,11 @@ xsh_spectrum_extract_range( xsh_spectrum * org, const double wmin,const double w
 
   xsh_msg("ima sx=%d",(int)cpl_image_get_size_x(org->flux));
   xsh_msg("ima sy=%d",(int)cpl_image_get_size_y(org->flux));
+  */
 
   size_y=(result->size_slit>1) ? result->size_slit: 1;
-  xsh_msg("out spectrum X size=%d",size_x);
-  xsh_msg("out spectrum Y size=%d",size_y);
+  //xsh_msg("out spectrum X size=%d",size_x);
+  //xsh_msg("out spectrum Y size=%d",size_y);
   check( result->flux = cpl_image_extract( org->flux,1,1,size_x,size_y));
   check( result->flux_header = cpl_propertylist_duplicate( org->flux_header ));
 
@@ -923,8 +925,8 @@ xsh_spectrum_cut_dichroic_uvb(cpl_frame* frame1d)
     phead = cpl_propertylist_load(fname, 0);
     pcatg=xsh_pfits_get_pcatg(phead) ;
 
-    xsh_msg("fname=%s",fname);
-    check(spectrum_i=xsh_spectrum_load( frame1d));
+    //xsh_msg("fname=%s",fname);
+    spectrum_i=xsh_spectrum_load( frame1d);
 
     check(wave_min=spectrum_i->lambda_min);
     check(wave_max=spectrum_i->lambda_max);
@@ -939,15 +941,17 @@ xsh_spectrum_cut_dichroic_uvb(cpl_frame* frame1d)
         return CPL_ERROR_NONE;
     }
     sprintf(oname,"tmp_%s",fname);
+    /*
     xsh_msg("wave_min=%g",wave_min);
     xsh_msg("wave_max=%g",wave_max);
     xsh_msg("wave_del=%g",wave_del);
     xsh_msg("wave_cut=%g",wave_cut);
     xsh_msg("naxis1=%d",naxis1);
     xsh_msg("xcut=%d",xcut);
-
+    */
     check(spectrum_o=xsh_spectrum_extract_range(spectrum_i, wave_min, wave_cut));
-    xsh_spectrum_save(spectrum_o, oname,pcatg);
+    cpl_frame* frm=xsh_spectrum_save(spectrum_o, oname,pcatg);
+    xsh_free_frame(&frm);
     sprintf(cmd,"mv  %s %s",oname,fname);
     assure(system(cmd)==0,CPL_ERROR_UNSPECIFIED,"unable to mv file");
     //cpl_frame_set_filename(frame1d,oname);
@@ -960,6 +964,79 @@ xsh_spectrum_cut_dichroic_uvb(cpl_frame* frame1d)
     return cpl_error_get_code();
 }
 
+
+cpl_error_code
+xsh_spectrum_orders_cut_dichroic_uvb(cpl_frame* frame1d,xsh_instrument* instr)
+{
+    cpl_propertylist* phead=NULL;
+    xsh_spectrum* spectrum_i=NULL;
+    xsh_spectrum* spectrum_o=NULL;
+
+    const char* pcatg=NULL;
+    const char* fname=NULL;
+    char oname[128];
+
+    int naxis1=0;
+    int xcut=0;
+    int next=0;
+
+    double wave_cut=XSH_UVB_DICHROIC_WAVE_CUT; /* 556 nm dichroic cut */
+    double wave_min=0;
+    double wave_max=0;
+    double wave_del=0;
+    char cmd[256];
+    fname=cpl_frame_get_filename(frame1d);
+    next=cpl_frame_get_nextensions(frame1d);
+
+    phead = cpl_propertylist_load(fname, 0);
+    pcatg=xsh_pfits_get_pcatg(phead) ;
+
+    //xsh_msg("fname=%s",fname);
+
+    spectrum_i=xsh_spectrum_load_order( frame1d, instr,0);
+
+    check(wave_min=spectrum_i->lambda_min);
+    check(wave_max=spectrum_i->lambda_max);
+    check(wave_del=spectrum_i->lambda_step);
+    check(naxis1=spectrum_i->size);
+
+    cpl_ensure_code(wave_max > wave_cut, CPL_ERROR_ILLEGAL_INPUT);
+    xcut = (int) ( (wave_cut-wave_min) / wave_del + 0.5 );
+    cpl_ensure_code(xcut <= naxis1, CPL_ERROR_ILLEGAL_INPUT);
+
+
+    if (xcut == naxis1) {
+        return CPL_ERROR_NONE;
+    }
+    sprintf(oname,"tmp_%s",fname);
+
+    check(spectrum_o=xsh_spectrum_extract_range(spectrum_i, wave_min, wave_cut));
+    cpl_frame* frm=xsh_spectrum_save(spectrum_o, oname,pcatg);
+    xsh_free_frame(&frm);
+    /* loop over each frame extensions */
+    cpl_frame* frame;
+     for(int i=3;i<next;i+=3) {
+
+         spectrum_i=xsh_spectrum_load_order( frame1d, instr,i);
+         frame=xsh_spectrum_save_order(spectrum_i, oname, pcatg,i);
+         xsh_spectrum_free(&spectrum_i);
+         xsh_free_frame(&frame);
+
+     }
+
+
+     sprintf(cmd,"mv  %s %s",oname,fname);
+     assure(system(cmd)==0,CPL_ERROR_UNSPECIFIED,"unable to mv file");
+
+    cleanup:
+
+    xsh_spectrum_free(&spectrum_i);
+    xsh_spectrum_free(&spectrum_o);
+    xsh_free_propertylist(&phead);
+
+    return cpl_error_get_code();
+}
+
 /** 
  * @brief save a spectrum
  * 
