@@ -1656,6 +1656,13 @@ void xsh_dfs_split_qth_d2(cpl_frameset * input, cpl_frameset** qth,
   cpl_frameset** d2);
 void xsh_dfs_filter( cpl_frameset* raws,const char* tag[], int size);
 
+void
+xsh_add_product_orders_spectrum( cpl_frame *frame,
+                          cpl_frameset *frameset,
+                          const cpl_parameterlist *parameters,
+                          const char *recipe_id,
+                          xsh_instrument* instr,
+                          cpl_frame ** result_frame);
 
 void xsh_add_product_spectrum( cpl_frame *product_frame, cpl_frameset *frameset,
   const cpl_parameterlist *parameters, const char *recipe_id,
