@@ -562,7 +562,7 @@ xsh_extract_clean_slice(const float* flux,
     const int slit_min, const int slit_max,
     const int nlambda,const int nslit,
     const int mask_hsize,
-    double* fluxval, double* errval, int* qualval);
+    double* fluxval, double* errval, int* qualval,float*,float*,float*);
 
 #define XSH_MATH_SQRT_2 1.4142135623730951
 void xsh_opt_extract( cpl_frame *sci_frame, cpl_frame *order_table_frame, 
