@@ -441,7 +441,7 @@ cpl_frame* xsh_check_remove_crh_single( int nb_raws_frame,
     xsh_add_temporary_file(result_name);
 
     check( result = xsh_remove_crh_single( subsky_frame,
-      instrument, crh_single_par, result_tag));
+      instrument, NULL,crh_single_par, result_tag));
   }
   else {
     check( result = cpl_frame_duplicate( subsky_frame));
@@ -454,7 +454,7 @@ cpl_frame* xsh_check_remove_crh_single( int nb_raws_frame,
 
 /*----------------------------------------------------------------------------*/
 /**
-  @brief Check functionfor sky subtraction on single frame
+  @brief Check function sky subtraction on single frame
   @param[in] do_subsky do sky subtraction?
   @param[in] src_frame source frame
   @param[in] ordertabedges_frame order edge table
@@ -474,26 +474,34 @@ cpl_frame* xsh_check_remove_crh_single( int nb_raws_frame,
 */
 /*----------------------------------------------------------------------------*/
 
-cpl_frame* xsh_check_subtract_sky_single( int do_subsky, cpl_frame *src_frame,
-  cpl_frame *ordertabedges_frame, 
-  cpl_frame *slitmap_frame, cpl_frame *wavemap_frame,
-  cpl_frame *loctab_frame, cpl_frame *masterflat_frame,
-  cpl_frame *definedbreakpoints_frame,
-  xsh_instrument *instrument, int nbkpts,
-  xsh_subtract_sky_single_param *sky_par,
-  cpl_frame **sky_spectrum, cpl_frame **sky_spectrum_eso, cpl_frame **sky_img,
-					  const char *prefix,const int clean_tmp)
+cpl_frame* xsh_check_subtract_sky_single( int do_subsky,
+                                          cpl_frame *src_frame,
+                                          cpl_frame *ordertabedges_frame,
+                                          cpl_frame *slitmap_frame,
+                                          cpl_frame *wavemap_frame,
+                                          cpl_frame *loctab_frame,
+                                          cpl_frame *definedbreakpoints_frame,
+                                          xsh_instrument *instrument,
+                                          int nbkpts,
+                                          xsh_subtract_sky_single_param *sky_par,
+                                          cpl_frame* ref_sky_list,
+                                          cpl_frame* sky_orders_chunks,
+                                          cpl_frame **sky_spectrum,
+                                          cpl_frame **sky_spectrum_eso,
+                                          cpl_frame **sky_img,
+                                          const char *prefix,
+                                          const int clean_tmp)
 {
-  char result_tag[256];
-  char result_name[256];
-  cpl_frame *result = NULL;
+    char result_tag[256];
+    char result_name[256];
+    cpl_frame *result = NULL;
 
   XSH_ASSURE_NOT_NULL( src_frame);
  
   if ( do_subsky == CPL_TRUE){
     xsh_msg("---Sky subtraction (single frame)");
     check( result = xsh_subtract_sky_single( src_frame, ordertabedges_frame,
-      slitmap_frame, wavemap_frame, loctab_frame,
+      slitmap_frame, wavemap_frame, loctab_frame,ref_sky_list,sky_orders_chunks,
       definedbreakpoints_frame, instrument, nbkpts, sky_par, sky_spectrum,
 					     sky_spectrum_eso, prefix,clean_tmp));
    sprintf( result_tag,"%s_SKY_%s", prefix, 
@@ -510,7 +518,39 @@ cpl_frame* xsh_check_subtract_sky_single( int do_subsky, cpl_frame *src_frame,
     check( result = cpl_frame_duplicate( src_frame));
   }
 
-  cleanup:
+    if ( do_subsky == CPL_TRUE){
+
+        XSH_ASSURE_NOT_NULL_MSG( src_frame,"Required science frame is missing");
+        XSH_ASSURE_NOT_NULL_MSG( ordertabedges_frame,"Required order table frame is missing");
+        XSH_ASSURE_NOT_NULL_MSG( slitmap_frame, "Required slitmap frame is missing, provide it or set compute-map to TRUE");
+        XSH_ASSURE_NOT_NULL_MSG( wavemap_frame,"Required wavemap frame is missing");
+        XSH_ASSURE_NOT_NULL_MSG( instrument,"Instrument setting undefined");
+        XSH_ASSURE_NOT_ILLEGAL( nbkpts > 1);
+        XSH_ASSURE_NOT_NULL_MSG( sky_par,"Undefined input sky parameters");
+        //XSH_ASSURE_NOT_NULL_MSG(ref_sky_list,"Null input reference sky line list");
+        XSH_ASSURE_NOT_NULL( prefix);
+
+        xsh_msg("---Sky subtraction (single frame)");
+        check( result = xsh_subtract_sky_single( src_frame, ordertabedges_frame,
+                        slitmap_frame, wavemap_frame, loctab_frame,ref_sky_list,
+                        sky_orders_chunks,
+                        definedbreakpoints_frame, instrument, nbkpts, sky_par,
+                        sky_spectrum, sky_spectrum_eso, prefix,clean_tmp));
+        sprintf( result_tag,"%s_SKY_%s", prefix,
+                 xsh_instrument_arm_tostring(instrument));
+        sprintf( result_name,"%s.fits", result_tag);
+        check( *sky_img = xsh_save_sky_model( src_frame, result, result_tag,
+                        instrument));
+        if(strstr(result_name,"TMPSKY")!=NULL) {
+            xsh_add_temporary_file(result_name);
+        }
+    }
+    else{
+        xsh_msg("[No sky subtraction]");
+        check( result = cpl_frame_duplicate( src_frame));
+    }
+
+    cleanup:
     return result;
 }
 /*----------------------------------------------------------------------------*/
