@@ -62,7 +62,7 @@
 /*-----------------------------------------------------------------------------
   Functions prototypes
   -----------------------------------------------------------------------------*/
-
+#define debug_extraction 0
 /*-----------------------------------------------------------------------------
   Implementation
   -----------------------------------------------------------------------------*/
@@ -347,7 +347,8 @@ cpl_error_code xsh_extract_clean_slice(const float* flux, const float* errs,
     int* qual, const double* lambda,
     const int ilambda, xsh_instrument* instrument, const int slit_min,
     const int slit_max, const int nlambda, const int nslit,
-    const int mask_hsize, double* fluxval, double* errval, int* qualval) {
+    const int mask_hsize, double* fluxval, double* errval, int* qualval,
+    float* pima,float* fima,float* rima) {
 
   int mask_size = 0;
 
@@ -395,6 +396,10 @@ cpl_error_code xsh_extract_clean_slice(const float* flux, const float* errs,
       *fluxval += flux[idx];
       *errval += (errs[idx] * errs[idx]);
       *qualval |= qual[idx];
+#if debug_extraction
+      fima[idx]=flux[idx];
+      rima[idx]=(flux[idx]-flux[idx])/errs[idx];
+#endif
     }
   } else { // 0<nbad<nslit
     xsh_msg_debug("Found %d bad pix at lambda=%g", nbad, lambda[ilambda]);
@@ -471,6 +476,9 @@ cpl_error_code xsh_extract_clean_slice(const float* flux, const float* errs,
           num_fct += prof[islit] * flux[idx] * inv_err2;
           den_fct += prof[islit] * prof[islit] * inv_err2 ;
         }
+#if debug_extraction
+        pima[idx]=prof[islit];
+#endif
       }/* end loop over slit */
       ipol_fct = num_fct / den_fct;
 
@@ -483,10 +491,18 @@ cpl_error_code xsh_extract_clean_slice(const float* flux, const float* errs,
           *fluxval += flux[idx];
           *errval += (errs[idx] * errs[idx]);
           *qualval |= qual[idx];
+#if debug_extraction
+          fima[idx]=flux[idx];
+          rima[idx]=(flux[idx]-flux[idx])/errs[idx];
+#endif
         } else {
           *fluxval += ipol_fct * prof[islit];
           *errval += (prof[islit] * prof[islit])/ den_fct;
           *qualval |= QFLAG_INTERPOL_FLUX;
+#if debug_extraction
+          fima[idx]=ipol_fct * prof[islit];
+          rima[idx]=(flux[idx]-ipol_fct * prof[islit])/((prof[islit] * prof[islit])/ den_fct);
+#endif
         }
       }
 
@@ -596,10 +612,17 @@ xsh_extract_clean_with_tag(cpl_frame * rec_frame, cpl_frame* loc_frame,
     double *res_lambda = NULL;
     float *res_flux = NULL, *res_errs = NULL;
     int *res_qual = NULL;
-
-
-
-
+    float* pima;
+    float* fima;
+    float* rima;
+#if debug_extraction
+    cpl_image* prof_ima =cpl_image_new(nlambda,nslit,CPL_TYPE_FLOAT);
+    cpl_image* flux_ima =cpl_image_new(nlambda,nslit,CPL_TYPE_FLOAT);
+    cpl_image* res_ima =cpl_image_new(nlambda,nslit,CPL_TYPE_FLOAT);
+    pima=cpl_image_get_data_float(prof_ima);
+    fima=cpl_image_get_data_float(flux_ima);
+    rima=cpl_image_get_data_float(res_ima);
+#endif
     xsh_msg_dbg_medium(
         "order %d nslit %d (%f,%f) nlambda %d (%f %f)", order, nslit, slitmin, slitmax, nlambda, lambdamin, lambdamax);
 
@@ -669,7 +692,7 @@ xsh_extract_clean_with_tag(cpl_frame * rec_frame, cpl_frame* loc_frame,
           }
           xsh_extract_clean_slice(flux, errs, qual, lambda,
               ilambda, instrument, slit_min, slit_max, nlambda, nslit,
-              mask_hsize, &fluxval, &errval, &qualval);
+              mask_hsize, &fluxval, &errval, &qualval,pima,fima,rima);
 
         }
 
@@ -711,7 +734,7 @@ xsh_extract_clean_with_tag(cpl_frame * rec_frame, cpl_frame* loc_frame,
           }
           xsh_extract_clean_slice(flux, errs, qual, lambda,
               ilambda, instrument, slit_min, slit_max, nlambda, nslit,
-              mask_hsize, &fluxval, &errval, &qualval);
+              mask_hsize, &fluxval, &errval, &qualval,pima,fima,rima);
         }
       }
       res_lambda[ilambda] = lambda[ilambda];
@@ -719,6 +742,19 @@ xsh_extract_clean_with_tag(cpl_frame * rec_frame, cpl_frame* loc_frame,
       res_errs[ilambda] = sqrt(errval);
       res_qual[ilambda] = qualval;
     }
+#if debug_extraction
+    //xsh_msg("saving image profile");
+    char prof_name[80];
+    sprintf(prof_name,"prof_ord_%d.fits",i);
+    cpl_image_save(prof_ima, prof_name, CPL_TYPE_DOUBLE, NULL, CPL_IO_DEFAULT);
+    sprintf(prof_name,"flux_ord_%d.fits",i);
+    cpl_image_save(flux_ima, prof_name, CPL_TYPE_DOUBLE, NULL, CPL_IO_DEFAULT);
+    sprintf(prof_name,"res_ord_%d.fits",i);
+    cpl_image_save(res_ima, prof_name, CPL_TYPE_DOUBLE, NULL, CPL_IO_DEFAULT);
+    cpl_image_delete(prof_ima);
+    cpl_image_delete(flux_ima);
+    cpl_image_delete(res_ima);
+#endif
 
   }
 
