@@ -79,7 +79,7 @@
   Functions prototypes
   -----------------------------------------------------------------------------*/
 
-static const char* fwhm_debug_mode = NULL;
+//static const char* fwhm_debug_mode = NULL;
 
 enum {
   LAMBDA_FOUND, LAMBDA_TOO_SMALL, LAMBDA_NOT_FOUND
