@@ -317,8 +317,13 @@ typedef struct {
 #define SUBTRACT_SKY_SINGLE_NBKPTS 1000
 
 enum sky_method {
-  BSPLINE_METHOD,
-  MEDIAN_METHOD
+    MEDIAN_METHOD,
+    BSPLINE_METHOD,
+    BSPLINE_METHOD1,
+    BSPLINE_METHOD2,
+    BSPLINE_METHOD3,
+    BSPLINE_METHOD4,
+    BSPLINE_METHOD5
 };
 
 
@@ -330,6 +335,11 @@ enum bspline_sampling {
 
 #define SKY_METHOD_PRINT(method)\
   (method) == BSPLINE_METHOD ? "BSPLINE" :  \
+  (method) == BSPLINE_METHOD1 ? "BSPLINE1" :  \
+  (method) == BSPLINE_METHOD2 ? "BSPLINE2" :  \
+  (method) == BSPLINE_METHOD3 ? "BSPLINE3" :  \
+  (method) == BSPLINE_METHOD4 ? "BSPLINE4" :  \
+  (method) == BSPLINE_METHOD5 ? "BSPLINE5" :  \
   (method) == MEDIAN_METHOD ? "MEDIAN" : "????"
 
 
