@@ -243,6 +243,12 @@
 #define XSH_QC_FPIXSAT_C "Fraction of saturated pixels"
 
 
+#define XSH_QC_NPIXSAT_TOT "ESO QC NPIXSAT TOT"
+#define XSH_QC_NPIXSAT_TOT_C "Total number of saturated pixels"
+#define XSH_QC_FPIXSAT_TOT "ESO QC FPIXSAT TOT"
+#define XSH_QC_FPIXSAT_TOT_C "Fraction of saturated pixels"
+
+
 #define XSH_QC_NPIXRANGE "ESO QC NPIXRANG"
 #define XSH_QC_NPIXRANGE_C "Number of pixels in range 4800-5200 ADU"
 #define XSH_QC_FPIXRANGE "ESO QC FPIXRANG"
@@ -607,6 +613,8 @@ void xsh_pfits_set_extract_slit_min(cpl_propertylist * plist, double value);
 void xsh_pfits_set_extract_slit_max(cpl_propertylist * plist, double value);
 void xsh_pfits_set_nsat(cpl_propertylist * plist, int value);
 void xsh_pfits_set_frac_sat(cpl_propertylist * plist, double value);
+void xsh_pfits_set_total_nsat(cpl_propertylist * plist, int value);
+void xsh_pfits_set_total_frac_sat(cpl_propertylist * plist, double value);
 void xsh_pfits_set_n_range_pix(cpl_propertylist * plist, int value);
 void xsh_pfits_set_frac_range_pix(cpl_propertylist * plist, double value);
 char* xsh_pfits_get_slit_value (const cpl_propertylist * plist,xsh_instrument * instrument );
@@ -658,6 +666,26 @@ xsh_plist_set_extra_keys(cpl_propertylist* plist,
 			 const char* qualdata,
                          const int type);
 
+cpl_error_code
+xsh_pfits_set_wcs1(cpl_propertylist* header,
+                   const double crpix1,
+                   const double crval1,
+                   const double cdelt1);
+cpl_error_code
+xsh_pfits_set_wcs2(cpl_propertylist* header,
+                   const double crpix2,
+                   const double crval2,
+                   const double cdelt2);
+cpl_error_code
+xsh_pfits_set_wcs3(cpl_propertylist* header,
+                   const double crpix3,
+                   const double crval3,
+                   const double cdelt3);
+
+cpl_error_code
+xsh_pfits_set_cd_matrix(cpl_propertylist* header,
+                        const double cdelt1,
+                        const double cdelt2);
 
 cpl_error_code 
 xsh_pfits_set_wcs(cpl_propertylist* header, 
