@@ -202,6 +202,12 @@ xsh_rec_list_rectify( xsh_rec_list *rec_list, int iorder, int irec,
 
   yfirst=ceil(fy-radius);
   ylast=floor(fy+radius);
+  /* to prevent to go outside the image we do the following check */
+  xfirst = (xfirst > 0) ? xfirst : 0;
+  xlast  = (xlast < nx) ? xlast  : nx;
+  yfirst = (yfirst > 0) ? yfirst : 0;
+  ylast  = (ylast < ny) ? ylast  : ny;
+
 
   /* If outside detector */
   if ( ix <0 || ix >= nx || iy < 0 || iy >= ny ) {
@@ -255,7 +261,7 @@ xsh_rec_list_rectify( xsh_rec_list *rec_list, int iorder, int irec,
         for(j=yfirst;j<ylast-1;j++) {
             j_nx=j*nx;
             for(i=xfirst;i<xlast-1;i++) {
-                qual_val |= qual[j_nx+i];         //UMR
+                qual_val |= qual[j_nx+i]; 
             }
         }
 
@@ -294,7 +300,7 @@ xsh_rec_list_rectify( xsh_rec_list *rec_list, int iorder, int irec,
       for(j=yfirst;j<ylast-1;j++) {
           j_nx=j*nx;
           for(i=xfirst;i<xlast-1;i++) {
-              qual_val |= qual[j_nx+i];         //UMR
+              qual_val |= qual[j_nx+i]; 
           }
       }
 
