@@ -166,7 +166,7 @@ cpl_frame * xsh_remove_crh_single(cpl_frame * in_sci_frame,
   float* sci_data = NULL;
   float* err_data = NULL;
   int* qua_data = NULL;
-  int* msk_data = NULL;
+  cpl_binary* msk_data = NULL;
 
   float* two_sub_sample_data = NULL;
   float* laplacian_data = NULL;
