@@ -883,7 +883,7 @@ xsh_efficiency_compute(cpl_frame* frm_sci,
 {
 
   cpl_image* ima_sci=NULL;
-  cpl_image* ima_ord=NULL;
+  cpl_vector* vec_ord=NULL;
   cpl_image* ima_obj=NULL;
   cpl_table* obj_tab=NULL;
 
@@ -946,12 +946,12 @@ xsh_efficiency_compute(cpl_frame* frm_sci,
   int neff_tot=0;
   double fclip=0;
   xsh_std_star_id std_star_id=0;
-  int ima_size_x=0;
-  //int ima_size_y=0;
+  int vec_size=0;
   XSH_ASSURE_NOT_NULL_MSG(frm_sci,"Null input sci frame set!Exit");
   XSH_ASSURE_NOT_NULL_MSG(frm_cat,"Null input std star cat frame set!Exit");
   XSH_ASSURE_NOT_NULL_MSG(frm_atmext,"Null input atmospheric ext frame set!Exit");
 
+
   check(next = cpl_frame_get_nextensions(frm_sci));
   //xsh_msg("next=%d",next);
   nord=(next+1)/3;
@@ -964,10 +964,12 @@ xsh_efficiency_compute(cpl_frame* frm_sci,
                                                      &naxis1,&biny);
 
 
+
   check(xsh_parse_catalog_std_stars(frm_cat,dRA,dDEC,STAR_MATCH_DEPSILON,
                                     &tbl_ref,&std_star_id));
 
 
+
   xsh_msg_dbg_medium("gain=%g airm=%g exptime=%g airmass=%g ra=%g dec=%g",
           gain,airmass,exptime,airmass,dRA,dDEC);
 
@@ -989,6 +991,7 @@ xsh_efficiency_compute(cpl_frame* frm_sci,
   check(cpl_table_fill_column_window_double(obj_tab,COL_NAME_INT_OBJ,0,nrow,-1));
 
 
+
   /* extract the object signal on a given slit
      extract the sky signal on 2 given slits
      computes the extracted sky per pixel on each sky window
@@ -1007,6 +1010,7 @@ xsh_efficiency_compute(cpl_frame* frm_sci,
                                 tbl_atmext,XSH_ATMOS_EXT_LIST_COLNAME_OLD);
   }
 
+ 
 
   if(tbl_ref == NULL) {
     xsh_msg_error("Provide std sar catalog frame");
@@ -1016,42 +1020,41 @@ xsh_efficiency_compute(cpl_frame* frm_sci,
 
   for(i=0;i<next;i+=3) {
 
-
+ 
      //xsh_msg("Processing extracted spectrum extension %d",i);
-     xsh_free_image(&ima_ord);
+     xsh_free_vector(&vec_ord);
      pobj=NULL;
      xsh_free_propertylist(&x_plist);
-     check(ima_ord=cpl_image_load(name_sci,CPL_TYPE_DOUBLE,0,i));
+     check(vec_ord=cpl_vector_load(name_sci,i));
      check(x_plist=cpl_propertylist_load(name_sci,i));
-     ima_size_x=cpl_image_get_size_x(ima_ord);
-     //ima_size_y=cpl_image_get_size_y(ima_ord);
-
-     //xsh_msg("naxis1=%d ima_ord nx=%d ny=%d",naxis1,ima_size_x,ima_size_y);
-     check(pobj=cpl_image_get_data_double(ima_ord));
+     vec_size=cpl_vector_get_size(vec_ord);
+ 
+     //xsh_msg("naxis1=%d vec_ord nx=%d",naxis1,vec_size);
+     check(pobj=cpl_vector_get_data(vec_ord));
      check(crval1=xsh_pfits_get_crval1(x_plist));
      check(cdelt1=xsh_pfits_get_cdelt1(x_plist));
      xsh_free_table(&tbl_ord);
-     tbl_ord=cpl_table_new(ima_size_x);
+     tbl_ord=cpl_table_new(vec_size);
      check(cpl_table_copy_structure(tbl_ord,obj_tab));
-     check(cpl_table_fill_column_window_int(tbl_ord,COL_NAME_ORD_OBJ,0,ima_size_x,-1));
-     check(cpl_table_fill_column_window_double(tbl_ord,COL_NAME_WAVE_OBJ,0,ima_size_x,-1));
-     check(cpl_table_fill_column_window_double(tbl_ord,COL_NAME_INT_OBJ,0,ima_size_x,-1));
+     check(cpl_table_fill_column_window_int(tbl_ord,COL_NAME_ORD_OBJ,0,vec_size,-1));
+     check(cpl_table_fill_column_window_double(tbl_ord,COL_NAME_WAVE_OBJ,0,vec_size,-1));
+     check(cpl_table_fill_column_window_double(tbl_ord,COL_NAME_INT_OBJ,0,vec_size,-1));
   
      check(po=cpl_table_get_data_int(tbl_ord,COL_NAME_ORD_OBJ));
      check(pw=cpl_table_get_data_double(tbl_ord,COL_NAME_WAVE_OBJ));
      check(pf=cpl_table_get_data_double(tbl_ord,COL_NAME_INT_OBJ));
-
+ 
 
      //xsh_msg("crval1=%g cdelt1=%g",crval1,cdelt1);
      ord=i/3;
-     for(j=0;j<ima_size_x;j++) {
+     for(j=0;j<vec_size;j++) {
         po[j]=ord;
         wav=crval1+cdelt1*j;
         pw[j]=wav;
         pf[j]=pobj[j];   
         //xsh_msg("j=%d Flux[%g]=%g",j,pw[j],pobj[j]);
      }
-
+ 
      //cpl_table_dump(tbl_ord,0,3,stdout);
      //sprintf(name_eff,"obj_ord%d.fits",ord);
      //check(cpl_table_save(tbl_ord,plist, x_plist,name_eff, CPL_IO_DEFAULT));
@@ -1073,6 +1076,8 @@ xsh_efficiency_compute(cpl_frame* frm_sci,
                                                  COL_NAME_WAVE_OBJ,
                                                  COL_NAME_INT_OBJ,
                                                  &ntot,&nclip));
+
+ 
      xsh_free_table(&tbl_ord);
      //cpl_table_dump(tbl_eff,1,2,stdout);
      nrow=cpl_table_get_nrow(tbl_eff);
@@ -1093,16 +1098,16 @@ xsh_efficiency_compute(cpl_frame* frm_sci,
      cpl_propertylist_append_double(plist,key_name,emed);
      cpl_propertylist_set_comment(plist,key_name,"Median efficiency");
 
-
+ 
      neff_tot+=ntot;
-     //xsh_msg("neff_tot=%d ima_size_x=%d",neff_tot,ima_size_x);
+     //xsh_msg("neff_tot=%d vec_size=%d",neff_tot,vec_size);
      if(ord==0) {
         tot_eff=cpl_table_duplicate(tbl_eff);
      } else {
         cpl_table_insert(tot_eff,tbl_eff,neff_tot);
      }
      nclip_tot+=nclip;
-    
+     
      //sprintf(name_eff,"eff_ord%d.fits",ord);
      //check(cpl_table_save(tbl_eff,plist, x_plist,name_eff, CPL_IO_DEFAULT));
   }
@@ -1136,15 +1141,15 @@ xsh_efficiency_compute(cpl_frame* frm_sci,
   check(cpl_table_save(tot_eff,plist, x_plist,fname, CPL_IO_DEFAULT));
 
   xsh_free_table(&obj_tab);
-
+ 
   check(frm_eff=xsh_frame_product(fname,tag,CPL_FRAME_TYPE_TABLE, 
                                   CPL_FRAME_GROUP_CALIB,
                                   CPL_FRAME_LEVEL_FINAL));
  
 
-
+ 
   cleanup:
-
+ 
  //if(phigh!=NULL) cpl_free(phigh);
 
 
@@ -1157,7 +1162,7 @@ xsh_efficiency_compute(cpl_frame* frm_sci,
 
   xsh_free_image(&ima_sci);
   xsh_free_vector(&rec_profile); 
-  xsh_free_image(&ima_ord);
+  xsh_free_vector(&vec_ord);
   xsh_free_image(&ima_obj);
   xsh_free_propertylist(&plist);
   xsh_free_propertylist(&x_plist);
