@@ -1270,10 +1270,10 @@ xsh_scired_slit_nod_get_calibs(cpl_frameset* raws,
     check( *skymask_frame = xsh_find_frame_with_tag( calib, XSH_SKY_LINE_LIST,
                              instrument));
   }
-  if((*response_ord_frame=xsh_find_frame_with_tag(calib,XSH_MRESPONSE_MERGE1D_SLIT,
+  if((*response_ord_frame=xsh_find_frame_with_tag(calib,XSH_RESPONSE_MERGE1D_SLIT,
                                                   instrument)) == NULL ) {
     check( *response_ord_frame = xsh_find_frame_with_tag(calib,
-                             XSH_RESPONSE_MERGE1D_SLIT,
+                             XSH_MRESPONSE_MERGE1D_SLIT,
                              instrument));
   }
   if(*response_ord_frame != NULL) {
@@ -1379,12 +1379,10 @@ xsh_respon_slit_nod_get_calibs(cpl_frameset* calib,
     check( *skymask_frame = xsh_find_frame_with_tag( calib, XSH_SKY_LINE_LIST,
 						     instrument));
   }
-  if((*response_ord_frame=xsh_find_frame_with_tag(calib,XSH_MRESPONSE_MERGE1D_SLIT,
-                                                  instrument)) == NULL ) {
-    check( *response_ord_frame = xsh_find_frame_with_tag(calib,
-							 XSH_RESPONSE_MERGE1D_SLIT,
-							 instrument));
-  }
+
+  check( *response_ord_frame = xsh_find_frame_with_tag(calib,
+							 XSH_RESPONSE_MERGE1D_SLIT, instrument));
+
   if(*response_ord_frame != NULL) { 
     *frm_atmext=xsh_find_frame_with_tag(calib,XSH_ATMOS_EXT,instrument);
     if(*frm_atmext==NULL) {
@@ -2000,6 +1998,7 @@ xsh_slit_stare_correct_crh_and_sky(xsh_localize_obj_param * loc_obj_par,
                                    cpl_frame* order_tab_edges, 
                                    cpl_frame* slitmap, 
                                    cpl_frame* wavemap,
+                                   cpl_frame* sky_map,
                                    cpl_frame* model_config,
                                    cpl_frame* single_frame_sky_sub_tab,
                                    xsh_instrument* instrument,
@@ -2040,7 +2039,7 @@ xsh_slit_stare_correct_crh_and_sky(xsh_localize_obj_param * loc_obj_par,
             check(xsh_frame_image_save(rmbkg,"rmbkg.fits"));
             xsh_msg("instrument=%p",instrument);
             check( sub_sky = xsh_check_subtract_sky_single( CPL_TRUE, rmbkg,
-                            order_tab_edges, slitmap, wavemap, NULL,
+                            order_tab_edges, slitmap, wavemap, sky_map,
                             single_frame_sky_sub_tab, instrument, sub_sky_nbkpts1,
                             sky_par,ref_sky_list, sky_orders_chunks,sky, sky_eso, sky_ima, sky_tag,clean_tmp));
             xsh_add_temporary_file(sky_name);
@@ -2556,12 +2555,12 @@ xsh_compute_wavelength_resampling_accuracy(cpl_frame* wavemap,
 
   cpl_image* wmap_ima=NULL;
   xsh_spectrum* s=NULL;
-  cpl_image* ima=NULL;
+  cpl_vector* vec=NULL;
   double wrms=0;
   double werr=0;
   int nline=1;
   cpl_propertylist* xhead=NULL;
-  cpl_image* xima=NULL;
+  cpl_vector* xvec=NULL;
   cpl_propertylist* phead=NULL;
   double csyer1=0;
 
@@ -2622,7 +2621,8 @@ xsh_compute_wavelength_resampling_accuracy(cpl_frame* wavemap,
 
      nbext = cpl_frame_get_nextensions( science);
      check(phead = cpl_propertylist_load( name, 0 ));
-     ima=cpl_image_load(name,CPL_TYPE_FLOAT,0,0);
+     //ima=cpl_image_load(name,CPL_TYPE_FLOAT,0,0);
+     vec=cpl_vector_load(name,0);
 
      sprintf(cmd,"mv  %s %s",name,tname);
      system(cmd);
@@ -2632,22 +2632,22 @@ xsh_compute_wavelength_resampling_accuracy(cpl_frame* wavemap,
      check(xsh_plist_set_wave_accuracy(phead,wrms,werr,csyer1));
 
 
-       check(cpl_image_save(ima, name, CPL_BPP_IEEE_FLOAT,
+       check(cpl_vector_save(vec, name, CPL_BPP_IEEE_FLOAT,
               phead,CPL_IO_DEFAULT));
        for( i = 0 ; i<=nbext ; i++ ) {
          int extension ;
-         xsh_free_image( &xima) ;
+         xsh_free_vector( &xvec) ;
          xsh_free_propertylist( &xhead) ;
-         check(xima = cpl_image_load( tname, CPL_TYPE_FLOAT, 0,i ));
+         check(xvec = cpl_vector_load( tname,i ));
          check(xhead = cpl_propertylist_load( tname ,i));
          if ( i == 0 ) {
            extension = CPL_IO_DEFAULT ;
-           check(cpl_image_save(xima, name, CPL_BPP_IEEE_FLOAT,
+           check(cpl_vector_save(xvec, name, CPL_BPP_IEEE_FLOAT,
                   phead,extension));
          }
          else {
            extension = CPL_IO_EXTEND ;
-       check(cpl_image_save(xima, name, CPL_BPP_IEEE_FLOAT,xhead,extension));
+       check(cpl_vector_save(xvec, name, CPL_BPP_IEEE_FLOAT,xhead,extension));
          }
        }
        sprintf(cmd,"rm  tmp_ima.fits");
@@ -2662,8 +2662,8 @@ xsh_compute_wavelength_resampling_accuracy(cpl_frame* wavemap,
   xsh_free_frame(&frm_tmp);
   xsh_free_propertylist( &phead) ;
   xsh_free_propertylist( &xhead) ;
-  xsh_free_image( &xima) ;
-  xsh_free_image( &ima) ;
+  xsh_free_vector( &xvec) ;
+  xsh_free_vector( &vec) ;
   xsh_pre_free(&pre);
   xsh_free_table(&tab);
   xsh_free_table(&ext);
