@@ -58,6 +58,108 @@
 
 /**@{*/
 
+/*-------------------------------------------------------------------------*/
+/**
+  @name        xsh_histogram
+  @memo        computes histogram
+  @param data  input data table
+  @param nbins input size of histogram bin
+  @param min   input min data to be considered in histogram
+  @param max   input max data to be considered in histogram
+  @param hist  output histogram: table with results:
+       # H: histogram
+       # X: array of data values corresponding to the center of each bin
+       # Xmean: 1D array corresponding to the mean of the data values entering
+                each histogram bin
+  Returns in case of succes -1 else.
+  @doc
+
+       Compute the histogram with the IDL intrinsic function HISTOGRAM, using
+       the input options specified by the parameters Dmin, Dmax, Bin. All
+       the computations are performed in floating-point arithmetics.
+       Then compute arrays of values corresponding to each histogram bin,
+       useful for plots, fitting, etc.
+
+
+ */
+/*--------------------------------------------------------------------------*/
+
+cpl_table*
+xsh_histogram(const cpl_table* data,
+              const char* cname,
+                const int nbins,
+                const double min,
+                const double max)
+{
+  cpl_table* histo=NULL;
+  cpl_table* tmp_tbl1=NULL;
+  cpl_table* tmp_tbl2=NULL;
+  int ntot=0;
+  int i=0;
+  int* phy=NULL;
+  double* pdt=NULL;
+  /* double* phx=NULL; */
+
+  double vtmp=0;
+  double vstp=0;
+  double vmax=0;
+  double vmin=0;
+
+  int h=0;
+
+
+  cpl_table_and_selected_double(data,cname,CPL_NOT_GREATER_THAN,max);
+
+  tmp_tbl1=cpl_table_extract_selected(data);
+  cpl_table_and_selected_double(tmp_tbl1,cname,CPL_GREATER_THAN,min);
+  tmp_tbl2=cpl_table_extract_selected(tmp_tbl1);
+  xsh_free_table(&tmp_tbl1);
+
+  ntot=cpl_table_get_nrow(tmp_tbl2);
+  /* not necessry to sort:
+    check_nomsg(sinfo_sort_table_1(tmp_tbl2,cname,FALSE));*/
+  vmin=cpl_table_get_column_min(tmp_tbl2,cname);
+  vmax=cpl_table_get_column_max(tmp_tbl2,cname);
+  vstp=(vmax-vmin)/(nbins-1);
+
+  histo=cpl_table_new(nbins);
+  cpl_table_new_column(histo,"HL",CPL_TYPE_DOUBLE);
+  cpl_table_new_column(histo,"HY",CPL_TYPE_INT);
+  cpl_table_new_column(histo,"HX",CPL_TYPE_DOUBLE);
+
+  cpl_table_fill_column_window(histo,"HL",0,nbins,0);
+  cpl_table_fill_column_window(histo,"HY",0,nbins,0);
+
+  phy=cpl_table_get_data_int(histo,"HY");
+
+  pdt=cpl_table_get_data_double(data,cname);
+  //cpl_table_save(data, NULL, NULL, "histo_data.fits", CPL_IO_DEFAULT);
+  for(i=0;i<nbins;i++) {
+    cpl_table_set_double(histo,"HX",i,(double)i);
+    vtmp=vmin+i*vstp;
+    cpl_table_set_double(histo,"HL",i,vtmp);
+  }
+  h=0;
+  for(i=0;i<ntot;i++) {
+    h=floor((pdt[i]-vmin)/vstp);
+    if((h<nbins) && (h>-1)) {
+      phy[h]++;
+    }
+  }
+  //cpl_table_save(histo, NULL, NULL, "histogram.fits", CPL_IO_DEFAULT);
+
+  xsh_free_table(&tmp_tbl2);
+
+
+  return histo;
+ cleanup:
+  xsh_free_table(&tmp_tbl1);
+  xsh_free_table(&tmp_tbl2);
+
+
+  return -1;
+
+}
 
 
 /*----------------------------------------------------------------------------*/
@@ -481,6 +583,54 @@ xsh_sort_table_2(cpl_table *t, const char *column1, const char *column2,
     return cpl_error_get_code();
 }
 
+/*---------------------------------------------------------------------------*/
+/**
+   @brief    Sort a table by two columns
+   @param    t        Table
+   @param    column1  1st column name
+   @param    column2  2nd column name
+   @param    column3  3rd column name
+   @param    reverse1  Flag indicating if 1st column values are sorted
+                       descending (CPL_TRUE) or ascending (CPL_FALSE)
+   @param    reverse2  Flag indicating if 2nd column values are sorted
+                       descending (CPL_TRUE) or ascending (CPL_FALSE)
+   @param    reverse3  Flag indicating if 3rd column values are sorted
+                       descending (CPL_TRUE) or ascending (CPL_FALSE)
+   @return   CPL_ERROR_NONE iff OK
+   @note derived from UVES pipeline
+
+   This is a wrapper of @c cpl_table_sort(). @em column1 is the more
+   significant column (i.e. values in @em column2 are compared, only if the
+   values in @em column1 are equal).
+*/
+/*---------------------------------------------------------------------------*/
+cpl_error_code
+xsh_sort_table_3(cpl_table *t, const char *column1, const char *column2,
+                 const char *column3,
+          cpl_boolean reverse1, cpl_boolean reverse2,cpl_boolean reverse3)
+{
+    cpl_propertylist *plist = NULL;
+
+    assure(t != NULL, CPL_ERROR_NULL_INPUT, "Null table");
+    assure(cpl_table_has_column(t, column1), CPL_ERROR_ILLEGAL_INPUT,
+       "No column '%s'", column1);
+    assure(cpl_table_has_column(t, column2), CPL_ERROR_ILLEGAL_INPUT,
+       "No column '%s'", column2);
+    assure(cpl_table_has_column(t, column3), CPL_ERROR_ILLEGAL_INPUT,
+           "No column '%s'", column3);
+
+    check_msg(( plist = cpl_propertylist_new(),
+        cpl_propertylist_append_bool(plist, column1, reverse1),
+        cpl_propertylist_append_bool(plist, column2, reverse2),
+        cpl_propertylist_append_bool(plist, column3, reverse3)),
+       "Could not create property list for sorting");
+    check_msg( cpl_table_sort(t, plist), "Could not sort table");
+
+  cleanup:
+    xsh_free_propertylist(&plist);
+    return cpl_error_get_code();
+}
+
 /*---------------------------------------------------------------------------*/
 /**
   @brief    Interpolate data points
